(function ( $ ) {
	'use strict';

	window.qodef = {};

	qodef.body         = $( 'body' );
	qodef.html         = $( 'html' );
	qodef.window       = $( window );
	qodef.windowWidth  = $( window ).width();
	qodef.windowHeight = $( window ).height();
	qodef.scroll       = 0;

	$( document ).ready(
		function () {
			qodef.scroll = $( window ).scrollTop();
			qodefBrowserDetection.init();
			qodefSwiper.init();
			qodefMagnificPopup.init();
			qodefAnchor.init();
			qodefAppear.init();
			qodefSplitting.init();
			qodefSocialMenu.init();
			qodefTextualLinks.init();
		}
	);

	$( window ).resize(
		function () {
			qodef.windowWidth  = $( window ).width();
			qodef.windowHeight = $( window ).height();
		}
	);

	$( window ).scroll(
		function () {
			qodef.scroll = $( window ).scrollTop();
		}
	);

	$( document ).on(
		'ginevra_trigger_get_new_posts',
		function () {
			qodefSwiper.init();
			qodefMagnificPopup.init();
		}
	);

	/*
	 * Browser detection functionality
	 */
	var qodefBrowserDetection = {
		init: function () {
			qodefBrowserDetection.addBodyClassName();
		},
		isBrowser: function ( name ) {
			var isBrowser = false;

			switch (name) {
				case 'chrome':
					isBrowser = /Chrome/.test( navigator.userAgent ) && /Google Inc/.test( navigator.vendor );
					break;
				case 'safari':
					isBrowser = /Safari/.test( navigator.userAgent ) && /Apple Computer/.test( navigator.vendor );
					break;
				case 'firefox':
					isBrowser = navigator.userAgent.toLowerCase().indexOf( 'firefox' ) > -1;
					break;
				case 'ie':
					isBrowser = window.navigator.userAgent.indexOf( 'MSIE ' ) > 0 || !! navigator.userAgent.match( /Trident.*rv\:11\./ );
					break;
				case 'edge':
					isBrowser = /Edge\/\d./i.test( navigator.userAgent );
					break;
			}

			return isBrowser;
		},
		addBodyClassName: function () {
			var browsers = [
				'chrome',
				'safari',
				'firefox',
				'ie',
				'edge',
			];

			$.each(
				browsers,
				function ( key, value ) {
					if ( qodefBrowserDetection.isBrowser( value ) && typeof qodef.body !== 'undefined' ) {
						if ( value === 'ie' ) {
							value = 'ms-explorer';
						}

						qodef.body.addClass( 'qodef-browser--' + value );
					}
				}
			);
		}
	};

	/**
	 * Init swiper slider
	 */
	var qodefSwiper = {
		init: function ( settings ) {
			this.holder = $( '.qodef-swiper-container' );

			// Allow overriding the default config
			$.extend(
				this.holder,
				settings
			);

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefSwiper.initSlider( $( this ) );
					}
				);
			}
		},
		initSlider: function ( $currentItem ) {
			var options = qodefSwiper.getOptions( $currentItem ),
				events  = qodefSwiper.getEvents(
					$currentItem,
					options
				);

			var $swiper = new Swiper(
				$currentItem,
				Object.assign(
					options,
					events
				)
			);
		},
		getOptions: function ( $holder, returnBreakpoints ) {
			var sliderOptions     = typeof $holder.data( 'options' ) !== 'undefined' ? $holder.data( 'options' ) : {},
				direction         = sliderOptions.direction !== undefined && sliderOptions.direction !== '' ? sliderOptions.direction : 'horizontal',
				spaceBetween      = sliderOptions.spaceBetween !== undefined && sliderOptions.spaceBetween !== '' ? sliderOptions.spaceBetween : 0,
				slidesPerView     = sliderOptions.slidesPerView !== undefined && sliderOptions.slidesPerView !== '' ? sliderOptions.slidesPerView : 1,
				centeredSlides    = sliderOptions.centeredSlides !== undefined && sliderOptions.centeredSlides !== '' ? sliderOptions.centeredSlides : false,
				sliderScroll      = sliderOptions.sliderScroll !== undefined && sliderOptions.sliderScroll !== '' ? sliderOptions.sliderScroll : false,
				loop              = sliderOptions.loop !== undefined && sliderOptions.loop !== '' ? sliderOptions.loop : true,
				autoplay          = sliderOptions.autoplay !== undefined && sliderOptions.autoplay !== '' ? sliderOptions.autoplay : true,
				speed             = sliderOptions.speed !== undefined && sliderOptions.speed !== '' ? parseInt(
					sliderOptions.speed,
					10
				) : 5000,
				speedAnimation    = sliderOptions.speedAnimation !== undefined && sliderOptions.speedAnimation !== '' ? parseInt(
					sliderOptions.speedAnimation,
					10
				) : 800,
				slideAnimation    = sliderOptions.slideAnimation !== undefined && sliderOptions.slideAnimation !== '' ? sliderOptions.slideAnimation : '',
				customStages      = sliderOptions.customStages !== undefined && sliderOptions.customStages !== '' ? sliderOptions.customStages : false,
				outsideNavigation = sliderOptions.outsideNavigation !== undefined && sliderOptions.outsideNavigation === 'yes',
				nextNavigation    = outsideNavigation ? '.swiper-button-next-' + sliderOptions.unique : $holder.find( '.swiper-button-next' ),
				prevNavigation    = outsideNavigation ? '.swiper-button-prev-' + sliderOptions.unique : $holder.find( '.swiper-button-prev' ),
				pagination        = $holder.find( '.swiper-pagination' ),
				paginationType    = sliderOptions.paginationType !== undefined && sliderOptions.paginationType !== '' ? sliderOptions.paginationType : 'bullets';

			if ( autoplay !== false ) {
				autoplay = {
					disableOnInteraction: false
				};
			} else if ( autoplay !== false && speed !== 5000 ) {
				autoplay = {
					delay: speed,
					disableOnInteraction: false
				};
			}

			var slidesPerView1440 = sliderOptions.slidesPerView1440 !== undefined && sliderOptions.slidesPerView1440 !== '' ? parseInt(
				sliderOptions.slidesPerView1440,
				10
				) : 5,
				slidesPerView1366 = sliderOptions.slidesPerView1366 !== undefined && sliderOptions.slidesPerView1366 !== '' ? parseInt(
					sliderOptions.slidesPerView1366,
					10
				) : 4,
				slidesPerView1024 = sliderOptions.slidesPerView1024 !== undefined && sliderOptions.slidesPerView1024 !== '' ? parseInt(
					sliderOptions.slidesPerView1024,
					10
				) : 3,
				slidesPerView768  = sliderOptions.slidesPerView768 !== undefined && sliderOptions.slidesPerView768 !== '' ? parseInt(
					sliderOptions.slidesPerView768,
					10
				) : 2,
				slidesPerView680  = sliderOptions.slidesPerView680 !== undefined && sliderOptions.slidesPerView680 !== '' ? parseInt(
					sliderOptions.slidesPerView680,
					10
				) : 1,
				slidesPerView480  = sliderOptions.slidesPerView480 !== undefined && sliderOptions.slidesPerView480 !== '' ? parseInt(
					sliderOptions.slidesPerView480,
					10
				) : 1;

			if ( ! customStages ) {
				if ( slidesPerView < 2 ) {
					slidesPerView1440 = slidesPerView;
					slidesPerView1366 = slidesPerView;
					slidesPerView1024 = slidesPerView;
					slidesPerView768  = slidesPerView;
				} else if ( slidesPerView < 3 ) {
					slidesPerView1440 = slidesPerView;
					slidesPerView1366 = slidesPerView;
					slidesPerView1024 = slidesPerView;
				} else if ( slidesPerView < 4 ) {
					slidesPerView1440 = slidesPerView;
					slidesPerView1366 = slidesPerView;
				} else if ( slidesPerView < 5 ) {
					slidesPerView1440 = slidesPerView;
				}
			}

			if ( direction === 'vertical' ) {
				slidesPerView = 1;
			}

			var options = {
				direction: direction,
				slidesPerView: slidesPerView,
				centeredSlides: centeredSlides,
				sliderScroll: sliderScroll,
				spaceBetween: spaceBetween,
				autoplay: autoplay,
				loop: loop,
				speed: speedAnimation,
				navigation: { nextEl: nextNavigation, prevEl: prevNavigation },
				pagination: {
					el: pagination,
					type: paginationType,
					formatFractionCurrent: function ( number ) {
						return ('0' + number).slice( -2 );
					},
					formatFractionTotal: function ( number ) {
						return ('0' + number).slice( -2 );
					},
					renderFraction: function ( currentClass, totalClass ) {
						return '<span class="' + currentClass + '"></span>' +
							'/' +
							'<span class="' + totalClass + '"></span>';
					},
					clickable: true
				},
				breakpoints: {
					// when window width is < 481px
					0: {
						slidesPerView: slidesPerView480
					},
					// when window width is >= 481px
					481: {
						slidesPerView: slidesPerView680
					},
					// when window width is >= 681px
					681: {
						slidesPerView: slidesPerView768
					},
					// when window width is >= 769px
					769: {
						slidesPerView: slidesPerView1024
					},
					// when window width is >= 1025px
					1025: {
						slidesPerView: slidesPerView1366
					},
					// when window width is >= 1367px
					1367: {
						slidesPerView: slidesPerView1440
					},
					// when window width is >= 1441px
					1441: {
						slidesPerView: slidesPerView
					}
				},
			};

			if ( slideAnimation.length ) {
				switch (slideAnimation) {
					case 'fade':
						options.effect     = 'fade';
						options.fadeEffect = {
							crossFade: true
						};

						break;
				}
			}

			return Object.assign(
				options,
				qodefSwiper.getSliderDatas( $holder )
			);
		},
		getSliderDatas: function ( $holder ) {
			var dataList    = $holder.data(),
				returnValue = {};

			for ( var property in dataList ) {
				if ( dataList.hasOwnProperty( property ) ) {
					// It's required to be different from data options because da options are all options from shortcode element
					if ( property !== 'options' && typeof dataList[property] !== 'undefined' && dataList[property] !== '' ) {
						returnValue[property] = dataList[property];
					}
				}
			}

			return returnValue;
		},
		getEvents: function ( $holder, options ) {
			return {
				on: {
					beforeInit: function () {
						if ( options.direction === 'vertical' ) {
							var height        = 0;
							var currentHeight = 0;
							var $item         = $holder.find( '.qodef-e' );

							if ( $item.length ) {
								$item.each(
									function () {
										currentHeight = $( this ).outerHeight();

										if ( currentHeight > height ) {
											height = currentHeight;
										}
									}
								);
							}
							$holder.css(
								'height',
								height
							);
							$item.css(
								'height',
								height
							);
						}
					},
					init: function () {
						$holder.addClass( 'qodef-swiper--initialized' );

						qodef.body.trigger(
							'ginevra_trigger_swiper_is_initialized',
							[$holder, options]
						);

						if ( options.sliderScroll ) {
							var scrollStart = false;

							$holder.on(
								'mousewheel',
								function ( e ) {
									e.preventDefault();

									if ( ! scrollStart ) {
										scrollStart = true;

										if ( e.deltaY < 0 ) {
											$holder[0].swiper.slideNext();
										} else {
											$holder[0].swiper.slidePrev();
										}

										setTimeout(
											function () {
												scrollStart = false;
											},
											1000
										);
									}
								}
							);
						}
					}
				}
			};
		}
	};

	qodef.qodefSwiper = qodefSwiper;

	/**
	 * Init magnific popup galleries
	 */
	var qodefMagnificPopup = {
		init: function ( settings ) {
			this.holder = $( '.qodef-magnific-popup' );

			// Allow overriding the default config
			$.extend(
				this.holder,
				settings
			);

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefMagnificPopup.initPopup( $( this ) );
					}
				);
			}
		},
		initPopup: function ( $currentItem ) {
			if ( $currentItem.hasClass( 'qodef-popup-item' ) ) {
				qodefMagnificPopup.initSingleImagePopup( $currentItem );
			} else if ( $currentItem.hasClass( 'qodef-popup-gallery' ) ) {
				qodefMagnificPopup.initGalleryPopup( $currentItem );
			}
		},
		initSingleImagePopup: function ( $popup ) {
			var type = $popup.data( 'type' );

			$popup.magnificPopup(
				{
					type: type,
					titleSrc: 'title',
					removalDelay: 350,
					mainClass: 'mfp-fade',
					image: {
						cursor: null
					},
					closeMarkup: '<button title="%title%" type="button" class="mfp-close">' + qodefGlobal.vars.iconClose + '</button>', // markup of an arrow button
				}
			);
		},
		initGalleryPopup: function ( $popup ) {
			var $items         = $popup.find( '.qodef-popup-item' ),
				itemsFormatted = qodefMagnificPopup.generateGalleryItems( $items );

			$items.each(
				function ( index ) {
					var $this = $( this );
					$this.magnificPopup(
						{
							items: itemsFormatted,
							gallery: {
								enabled: true,
								arrowMarkup: '<button title="%title%" type="button" class="mfp-arrow mfp-arrow-%dir%">' + qodefGlobal.vars.iconArrowLeft + '</button>', // markup of an arrow button
							},
							index: index,
							type: 'image',
							mainClass: 'mfp-fade',
							removalDelay: 350,
							image: {
								cursor: null
							},
							closeMarkup: '<button title="%title%" type="button" class="mfp-close">' + qodefGlobal.vars.iconClose + '</button>', // markup of an arrow button
						}
					);
				}
			);
		},
		generateGalleryItems: function ( $items ) {
			var itemsFormatted = [];

			if ( $items.length ) {
				$items.each(
					function () {
						var $thisItem     = $( this );
						var itemFormatted = {
							src: $thisItem.attr( 'href' ),
							title: $thisItem.attr( 'title' ),
							type: $thisItem.data( 'type' )
						};
						itemsFormatted.push( itemFormatted );
					}
				);
			}

			return itemsFormatted;
		}
	};

	qodef.qodefMagnificPopup = qodefMagnificPopup;

	var qodefAnchor = {
		items: '',
		init: function ( settings ) {
			this.holder = $( '.qodef-anchor' );

			// Allow overriding the default config
			$.extend(
				this.holder,
				settings
			);

			if ( this.holder.length ) {
				qodefAnchor.items = this.holder;

				qodefAnchor.clickTrigger();

				$( window ).on(
					'load',
					function () {
						qodefAnchor.checkAnchorOnScroll();
						qodefAnchor.checkAnchorOnLoad();
					}
				);
			}
		},
		clickTrigger: function () {
			qodefAnchor.items.on(
				'click',
				function ( e ) {
					var $anchorItem = qodefAnchor.getAnchorItem( this ),
						anchorURL   = $anchorItem.attr( 'href' ),
						hash        = $anchorItem.prop( 'hash' ).split( '#' )[1],
						pageURL     = window.location.href,
						pageHash    = pageURL.indexOf( '#' ) > -1 ? pageURL.split( '#' )[1] : 0;

					if (
						anchorURL.indexOf( 'http' ) < 0
						|| anchorURL === pageURL
						|| (pageHash !== 0 && anchorURL.substring(
						0,
						anchorURL.length - hash.length - 1
						) === pageURL.substring(
						0,
						pageURL.length - pageHash.length - 1
						))
						|| (pageHash === 0 && anchorURL.substring(
						0,
						anchorURL.length - hash.length - 1
						) === pageURL)
					) {
						e.preventDefault();
					}

					qodefAnchor.animateScroll(
						$anchorItem,
						hash
					);
				}
			);
		},
		checkAnchorOnLoad: function () {
			var hash = window.location.hash.split( '#' )[1];

			if ( typeof hash !== 'undefined' && hash !== '' && qodefAnchor.items.length ) {
				qodefAnchor.items.each(
					function () {
						var $anchorItem = qodefAnchor.getAnchorItem( this );

						if ( $anchorItem.attr( 'href' ).indexOf( hash ) > -1 ) {
							qodefAnchor.animateScroll(
								$anchorItem,
								hash
							);
						}
					}
				);
			}
		},
		checkAnchorOnScroll: function () {

			if ( qodef.windowWidth > 1024 ) {
				var $target = $( '#qodef-page-inner *[id]' );

				if ( $target.length ) {
					$target.each(
						function () {
							var $currentTarget = $( this ),
								$anchorItem    = $( '[href*="#' + $currentTarget.attr( 'id' ) + '"]' );

							if ( $anchorItem.length ) {
								if ( qodefAnchor.isTargetInView( $currentTarget ) ) {
									qodefAnchor.setActiveState( $anchorItem );
								}

								$( window ).scroll(
									function () {
										if ( qodefAnchor.isTargetInView( $currentTarget ) ) {
											qodefAnchor.setActiveState( $anchorItem );
										} else {
											$anchorItem.removeClass( qodefAnchor.getItemClasses( $anchorItem ) );
										}
									}
								);
							}
						}
					);
				}
			}
		},
		isTargetInView: function ( $target ) {
			var rect           = $target[0].getBoundingClientRect(),
				percentVisible = 20,
				windowHeight   = (window.innerHeight || document.documentElement.clientHeight);

			return ! (
				Math.floor( 100 - (((rect.top >= 0 ? 0 : rect.top) / +-(rect.height / 1)) * 100) ) < percentVisible ||
				Math.floor( 100 - ((rect.bottom - windowHeight) / rect.height) * 100 ) < percentVisible
			);
		},
		getAnchorItem: function ( item ) {
			var isItemLink = item.tagName === 'A';

			return isItemLink ? $( item ) : $( item ).children( 'a' );
		},
		animateScroll: function ( $item, hash ) {
			var $target = hash !== '' ? $( '[id="' + hash + '"]' ) : '';

			if ( $target.length ) {
				var targetPosition = $target.offset().top,
					scrollAmount   = targetPosition - qodefAnchor.getHeaderHeight() - qodefGlobal.vars.adminBarHeight;

				qodefAnchor.setActiveState( $item );

				qodef.html.stop().animate(
					{
						scrollTop: Math.round( scrollAmount )
					},
					1000,
					function () {
						//change hash tag in url
						if ( history.pushState ) {
							history.pushState(
								null,
								'',
								'#' + hash
							);
						}
					}
				);

				return false;
			}
		},
		getHeaderHeight: function () {
			var height = 0;

			if ( qodef.windowWidth > 1024 && qodefGlobal.vars.headerHeight !== null && qodefGlobal.vars.headerHeight !== '' ) {
				height = parseInt(
					qodefGlobal.vars.headerHeight,
					10
				);
			}

			return height;
		},
		setActiveState: function ( $item ) {
			var isItemLink = ! $item.parent().hasClass( 'qodef-anchor' ),
				classes    = qodefAnchor.getItemClasses( $item );

			qodefAnchor.items.removeClass( classes );

			if ( isItemLink ) {
				$item.addClass( classes );
			} else {
				$item.parent().addClass( classes );
			}
		},
		getItemClasses: function ( $item ) {
			// Main anchor item class plus header item classes if item is inside header
			var activeClass     = 'qodef-anchor--active',
				menuItemClasses = $item.parents( '#qodef-page-header' ) ? ' current-menu-item current_page_item' : '';

			return activeClass + menuItemClasses;
		}
	};

	qodef.qodefAnchor = qodefAnchor;

	/**
	 * Wait element images to loaded
	 */
	var qodefWaitForImages = {
		check: function ( $element, callback ) {
			if ( $element.length ) {
				var images = $element.find( 'img' );

				if ( images.length ) {
					var counter = 0;

					for ( var index = 0; index < images.length; index++ ) {
						var img = images[index];

						if ( img.complete ) {
							counter++;

							if ( counter === images.length ) {
								callback.call( $element );
							}
						} else {
							var image = new Image();

							image.addEventListener(
								'load',
								function () {
									counter++;
									if ( counter === images.length ) {
										callback.call( $element );
										return false;
									}
								},
								false
							);
							image.src = img.src;
						}
					}
				} else {
					callback.call( $element );
				}
			}
		},
	};

	qodef.qodefWaitForImages = qodefWaitForImages;

	/**
	 * Init animation on appear
	 */
	var qodefAppear = {
		init: function () {
			this.holder = $( '.qodef--has-custom-appear' );

			function getRandomArbitrary( min, max ) {
				return Math.floor( Math.random() * (max - min) + min );
			}

			if ( this.holder.length ) {
				this.holder.each( function () {
					var holder    = $( this ),
						randomNum = getRandomArbitrary(
							10,
							400
						);

					if ( holder.hasClass( 'qodef--appear-delay-random' ) ) {
						qodefCore.qodefIsInViewport.check(
							holder,
							function () {
								setTimeout(
									function () {
										holder.addClass( 'qodef--custom-appeared ' );
									},
									randomNum
								);
							}
						);
					} else if ( holder.hasClass( 'qodef--appear-delay' ) ) {
						qodefCore.qodefIsInViewport.check(
							holder,
							function () {
								setTimeout(
									function () {
										holder.addClass( 'qodef--custom-appeared ' );
									},
									50
								);
							}
						);
					} else {
						qodefCore.qodefIsInViewport.check(
							holder,
							function () {
								holder.addClass( 'qodef--custom-appeared ' );
							}
						);
					}
				} );
			}
		},
	};

	qodef.qodefAppear = qodefAppear;

	/**
	 * Init splitting.js
	 */
	var qodefSplitting = {
		init: function () {
			this.holder = $( '.qodef--splitting' );

			if ( this.holder.length ) {
				this.holder.each( function () {
					Splitting();
				} );
			}
		},
	};

	qodef.qodefSplitting = qodefSplitting;

	var qodefSocialMenu = {
		init: function () {
			var $items = $( '.menu-socials-header-container > ul > li > a' );

			if ( $items.length ) {
				$items.each(
					function () {
						var $item       = $( this ),
							itemText    = $item.text(),
							itemIcon    = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="80.746px" height="12.084px" viewBox="0 0 80.746 12.084" preserveAspectRatio="none" enable-background="new 0 0 80.746 12.084" xml:space="preserve"> <g fill="currentColor"><path d="M80.635 8.387c.091-.245.177-.826.041-.731l-.268.962.227-.231z"></path><path d="M80.201 6.451c-.224.45-.529 1.257-.605 2.169.304-.917.264-.521.614-1.613.137-.095.143.347.056.702.088-.243.138.244.315-.357-.006-.782-.194-.843-.508-.252-.003-.222.085-.471.128-.649z"></path><path d="m68.916 3.47.065.123c-.015-.067-.038-.105-.065-.123z"></path><path d="M61.732 2.557c.056-.021.081-.12.086-.21-.052.063-.096.123-.086.21z"></path><path d="M60.518 1.438c.026.032.049.046.072.068-.027-.091-.054-.142-.072-.068z"></path><path d="m68.916 3.47-.17-.325c-.037.321.081.247.17.325z"></path><path d="M78.241 8.554c.047-.041.094-.127.144-.241-.039.037-.075.067-.112.087-.01.053-.02.099-.032.154z"></path><path d="m72.167 2.939.059.005c.026-.114.057-.247.09-.396l-.149.391z"></path><path d="M74.631 3.075c-.051-.043-.174.791-.239 1.154.073-.341.134-.5.19-.56.021-.158.037-.35.049-.594z"></path><path d="m78.268 5.094.086-.104c-.024.033-.059.062-.086.104z"></path><path d="M70.431 2.593c.007-.125.008-.235.004-.301-.009.104-.009.205-.004.301z"></path><path d="M2.865 11.348c-.001-.061-.002-.098-.003-.15-.012.085-.016.145.003.15z"></path><path d="m.012 7.208.039-.046c.003-.16.005-.316.008-.473l-.047.519z"></path><path d="M58.254.345c.005.008.006.009.01.016.06-.096.026-.08-.01-.016z"></path><path d="M37.548 1.784c.285.736-.311.991.098 1.804-.056-.327.226-1.335-.098-1.804z"></path><path d="M78.2 8.435c-.033.004-.066.006-.097-.007.039.033.069.036.097.007z"></path><path d="M37.646 3.588v.006l.042.077c-.018-.034-.029-.055-.042-.083z"></path><path d="M53.021.901c.014.148.037.261.062.368-.005-.086-.02-.192-.062-.368z"></path><path d="m56.919 2.043-.097-.113c.039.077.07.103.097.113z"></path><path d="M51.038 2.132c-.055-.063-.075-.179-.143-.063.008.043.015.072.024.102.023-.115.056-.172.119-.039z"></path><path d="M48.953 2.223c.016.06.03.111.045.168l.064-.048-.109-.12z"></path><path d="M9.238 10.767c-.056-.235-.095-.496-.127-.753.057.596-.243.821.127.753z"></path><path d="M78.319 8.086c-.047.208-.082.309-.119.349.024-.006.049-.019.073-.034.027-.123.047-.24.046-.315z"></path><path d="m51.165 8.784-.327-.111c.093.078.212.116.327.111z"></path><path d="m24.158 9.73-.068.107c.031.017.056-.01.068-.107z"></path><path d="M49.883 8.837c-.068-.294-.137-.465-.204-.574-.011.066-.024.121-.029.219l.233.355z"></path><path d="M9.11 10.005c0 .003.001.009.001.009s-.001-.006-.001-.009z"></path><path d="M6.987 12.084c.319.013.114-1.09.161-1.728.367-.328.202.809.351 1.371.228-.302.372-1.325.55-1.288.02.182.057.247.024.478.218-.89.741-.07.987-1.187.026.098.041.19.05.274-.07-.554-.1-1.117-.106-1.519.141-.024.232-.709.315.013-.087-.018-.082.275-.113.503l.135-.319c.177 1.035-.188.366-.155 1.136.276-.348.575-1.222.808-.935.092 1.016-.503.36-.168 1.255l-.36-.376c.331 1.596-.214-.104.101 1.604.468.277.486-.534.951-.259.075-.571-.072-.835.003-1.406.59-1.051.625 2.532 1.031 1.151.089-.685.071-1.975.439-1.312l-.057 1.156c.443.091.166-1.667.662-.917-.058.456-.323.399-.25.532.343.893.176-.663.403-.676l.101 1.017c.457-.186.929-.948 1.432-1.161-.011.304-.081.628.058.933.621-.542 1.394.051 2.057.609l.184-.895c.056.006.128.391.078.564.265.317-.022-.559.073-.911.134-.07.215.493.144.763.383-.773 1.118-1.686 1.633-.774l-.071.267c.377.333.276-1.827.657-1.029l-.052.16c.79.329 1.577-.528 2.252.752.02-1.273.795.508.716-1.26.498.843.396 1.167 1.053 1.709.17.069.163-1.119.352-1.318l.073.921.202-.987.229 1.093.172-.251c-.079-.05-.191-.402-.199-.668.265-.44.77.588.813 1.061l.643-.832c.013.372-.095.508-.17.751.303-.969.142.967.419.078-.062-.206-.017-.551-.023-.737.215.545.603.52.871.263l-.006.639c.53.123 1.069-.389 1.651-.422-.231-.279-.268-1.385-.105-1.504l.144.97c.063-.612-.207-.354-.037-1.109.226.096.231 1.097.131 1.424l.238-.358c.037.289-.013.447 0 .819.062-.613.531.942.606-.12l.037.289c.582-.037.82-.393 1.29-.479-.056-.842.145-.669.233-1.36.369.242.804.874 1.217.771.262-.441.031-.72.125-1.229.08.765.492.662.317 1.229.493-.163.63-.201 1.218-.872-.096-.31-.184-.441-.163-.706.106-.135.287.302.298.671l-.024.082c.628-1.204 1.81 2.109 2.259.469l-.025.081.526-.873c.279.113-.12.587.114 1.048.54-1.323 1.012.115 1.473-.772.56 2.233 1.421-.258 2.063 1.148l-.067-.53c.106-.532.19.293.303.407-.042-.412-.185-.468-.116-.764 1.152-.731 2.506.63 3.746 1.036.451.118.098-2.771.73-1.531l-.104.999c.835-1.239 1.837-.069 2.665-1.106-.042.23-.029.527-.115.527.219.711.686.007.663-.58.14.061.056.528.153.824.203.416.427-.938.556-.227.021.115-.042.235-.074.293.106-.354.567.064.418-.761.345.383.616-.395.897.086.138-.936.58.423.588-.892.024 1.356.615 1.069.804.423-.057.413.194.418.131.988.235-.024.444-.28.383-.976.481 1.614.845-1.324 1.145.751.685-.744 1.33-1.251 1.962-1.581-.003 1.354-.701.149-.648 1.568.589-.569.922-1.737 1.524-1.423.157.182-.081.589-.131.82.597-.575 1.161.109 1.691-.622-.001.126-.059.263-.112.366.104-.044.244.2.231-.416l-.103.167c-.171-.895.417-1.862.438-2.334-.18 1.762.532.446.243 2.672.069-.115.156-.406.142-.817.104.12.135.36.029.828.378-.333.247-.987.59-.972-.003.298-.073.413-.11.763.176-.579.355-1.159.644-.906-.02.18.012.414-.074.409.496-.088.868-1.542 1.409-.978-.184 1.293.179.427.187 1.547l.299-.332-.106-.544c.256.018.501-.789.714-.413l-.201.454.486-.194-.263-.435c.275-.567.007-1.418.344-1.094-.073.112.26.023.375.688v.003c.138-.352.281-.721.464-.437.038.36-.079 1.236-.055 1.476.156-.931.61-.236.806-1.228-.062.232-.086.82-.073.94l.134-.756c.11.247.123.365.086.833.354.152-.059-1.423.344-.796-.036.061-.024.175-.099.287.414.335.849-.451 1.226-.063.062 1.131-.355.263-.269 1.218.57-.18 1.24-1.316 1.772-1.001l-.095-.132c.171-1.582.36.816.682.088-.075.112-.145.874-.115.699.356.282.786-.334 1.393-.79l-.101.402c.193.38.564.253.787.456.103-.401.234-.325.199-.924.533 2.381 1.521-1.153 1.991.857-.078-.005-.219.334-.158.344l.588-.311c.026-.695-.029-.427-.092-.978.111-.4.302-.698.44-.683-.299.428-.112 1.108-.046 1.505.004-.213.065-.441.079-.658.159 1.261.196-1.381.506-.508l-.061.359c.168-.168.358-.63.509-.508-.024.805-.201.354-.284 1.008.228-.02.616-1.457.729-.639-.122.21-.26.198-.381.407.113.962.165.727.312.894l-.014-.022.325.468-.064-.266c.533-2.042.614-.312 1.167-1.626-.535 1.242-.156.736-.302 1.634.063.262.172.56.098.808.272-.706.217.607.608-.426-.028.291.186.05.046.773.26-.201.016-.511.084-.872.498-.957.655 1.321 1.359.047.521-.486.756-1.447 1.247-1.863.064.484-.282 1.033-.282 1.033.155.462.333.411.598.116-.084.244-.075.465-.065.8.179-.049.288-1.032.438-.57-.093.315-.229.821-.363 1.131.24-.233.527-.739.778-.965-.034.511-.257.741-.385 1.058.267-.188.671-.356.886-1.14l-.098-.309c.092-.023-.079.69-.166.825-.307.59-.235-.323-.196-.614l.179-.16c.146-1.715-.639.173-.913.026l.33-1.21-.475.971c-.011-.331.057-1.026.235-1.186-.115-.645-.262.406-.335-.303-.004-.109.016-.167.042-.213l-.269.332c.082-.252.104-.876.205-.676-.269-.774-.755.823-.753-.135l.044-.07c-.588.33-.19.896-.738 1.896l.065-2.279-.186.905c-.05-.041-.146-.127-.075-.486-.289.587-.021.4-.223.967-.141-.877-.769.297-.63-1.16-.187.679.178.562-.166 1.008.13-1.564-.356.229-.5-.513.178-.795.351-.343.203-1.087-.32 1.34-.429-.354-.667-.117-.145 1.08-.496.399-.878.721.064-.361-.569-.67-.845-1.1l.029-.181c-.181 1.088-.483.844-.744 1.042.077-.654.146-.908.307-1.187l-.226-.021c-.089.345-.178.522-.335.631l.139-.813c-.306.012-.695.887-1.028.316-.091.764.104 2.153-.343 2.634.023-.415.072-1.123.193-1.284-.039.052-.154.334-.207.152l.225-.684c-.146-.319-.145.574-.277.499.056-.59-.065-.429-.003-.896.041-.055.1.253.174.025-.147-.117-.308-.481-.332-.934-.016.337-.069.795-.191.863-.302.021-.041-.718-.19-1.035-.107.405-.263-.034-.341.849-.087-.012-.069-.425-.084-.666-.187.378-.733.058-.631 1.01l.034.064c-.009.019-.018.019-.028.039h.001H69c-.568.84-1.012-.579-1.541-.237l.021-.296c-.321.314-.68.149-.93.77-.088-.007-.178-.555-.12-.904-.242.203-.284.541-.59.039.258-.508-.056-.461.257-.369-.284-.267-.33-.743-.69.054.146-.754-.18-.964-.333-.742l.185.55c-.165.104-.302.032-.44-.038l.122-.994c-.567-1.236-1.189 2.022-1.58-.025-.187.691.316.503.142 1.314-.274-.146-.521-1.589-.611-1.595-.372-.567-.405 1.444-.798 1.051.043.357.064 1.31-.242 1.634-.275-.143-.309-1.506-.124-1.785.068-.027.099.087.093.207.094-.125.218-.273.115-.664l-.045.354c-.131-.368-.521-.345-.417-.925-.222.331-.104.58.05.771-.354-.535-.568-.028-.934-.378.056.196.103.615.044.61-.538-.443-.251.674-.621.828-.201-.544.093-1.295-.284-.843-.223-.369-.037-.945.058-1.234-.349.684-.632-.455-.828-.582L59.142 0c-.109.17-.198.164-.288.162l.098.713c-.104-.126-.194-.128-.19-.425-.111.466.074 1.185-.144 1.821-.138-.362-.427.386-.472-.56.439.323-.045-.949.33-1.1-.073.112-.161.107-.267-.019-.016-.105.016-.195.045-.249-.422-.848-.198 1.067-.636 1.043.057-.532-.102-1.011-.173-.897.177.012.084.889-.077 1.296-.28-.417-.303.307-.449.257l.167.196c-.055.532-.194.461-.388.628-.019-.415.176-.284.105-.468-.21.937-.494-.975-.791-.34-.143-.357-.022-1-.147-1.242-.332.697-.375-.722-.726-.145.112.714.127.538-.114 1.24l.578-.515-.362 1.048c.175.007.365-.457.472-.337-.172.587-.155.408-.065 1.001-.251-1.069-.467.635-.752-.085l-.016-1.769c-.433-.781-.731.924-1.281.49l.181.304c-.06.705-.334.104-.503.394.004-.593-.111-.806-.194-1.172.019.438-.4-.032-.421 1.151l-.262-.775c-.448-.311-.455 1.697-.88 1.505.108-.646-.096-1.063.174-1.528-.142-.003-.271-.108-.262.301-.094-.367-.365.805-.512.248-.051.263-.05.884-.209.841-.021-.12-.009-.293-.009-.293.009.292-.232.408-.073 1.058-.494-1.829-1.195.185-1.631-1.387-.298.211-.658.417-.934.471.011-.178-.012-.295.044-.235-.407-.535-.162 1.709-.623 1.112-.265-.947.208-.527.054-.884-.148-1.944-.514.288-.859-.837l.065-.117c-.257-.652-.513.76-.885.637 0 0 .009-.174-.013-.295-.2 1.008-.654 1.363-.989 1.659.068-.768.138-.412.03-1.183-.151.12.112 1.241-.189 1.475-.125-.411-.371-.762-.446-1.586l.294-.062c-.21-1.06-.382.059-.548-.118l-.006-.468c-.447.178-.387 1.354-.879 1.299l.071.351c-.198 1.181-.262-.643-.477.239l-.15-1.178c-.16.295-.548 1.179-.849 1.419.124-.887.466-1.357.664-1.891-.175.002-.589.122-.644.71.063-.118.134-.412.215-.234-.158.941-.41 1.415-.758 1.414-.084-2.298-.94-.521-1.309-2.28-.558.89-1.243-.278-1.951-.093.377 1.765-.205.065-.034 1.892-.158.129-.224.104-.247-.015l-.581-1.058c-.157-.524.13-.414.086-.824-.376-.115-.208-.765-.485-1.234.097.651-.061.946-.286.711l.354.823c-.44 1.01-.552-1.505-.997-.505l.121-.587c-.241.356-.975.059-1.124 1.548-.063-.207-.161-.703-.055-.844-.646-.173-1.283 1.669-1.839.802l.014-.451c-.107.139-.141.856-.321.417-.007-.186.014-.45-.043-.473-.051.159-.253.808-.428.559l.095-.514c-.658-.539-.848 1.297-1.338 1.643-.1-1.317-.615-1.708-.871-1.902l-.007-.187c-.724-.107-1.124 1.185-1.744 1.753-.519-1.398-1.432-.491-2.151-1.242.119.231.063 1.027-.044 1.168-.175-.255-.356.946-.425-.263l.057.019c-.207-1.175-.5-.835-.749-.851l.08 1.583c-.819-2.25-1.631.97-2.137-1.063-.126.407-.319.416-.445.822l-.054-.848c-.447-.184-.671-.274-1.189-.033l.065-.613c-.305-.032-.204 2.471-.479 2.541l-.174-1.258c-.525.061-1.13-1.02-1.569.163-.004-.186-.014-.553.067-.609-.249-.018-1.01-.793-.804.938-.082-1.131-.548-.075-.799.442l-.011-.838c-.169 1.082-.158 1.374-.474 1.691-.086-.104-.112-.663.007-.457-.292-.419-.155.805-.504.381l.085-.541c-.275-.046-.235.238-.346.87-.15.346-.529-.177-.616-.929-.008.462-.119 1.087-.293.881-.039-.284.009-.465.033-.553-.488-.54-.617 1.007-.978.205-.022-.276-.051-.414-.082-.495.361.001.653.031.63.094-.046-.77-.344-.89-.177-1.964-.196.592-.522 1.874-.826 1.527-.018-.074-.035-.146-.053-.265l.024-.088c-.069-.073-.124.002-.172.134-.097-.121-.159-.212-.247-.219-.068-.635-.351-.325-.497-.349.058.841-.14.716.076 1.402-.026-.06.021-.103.116-.143.021-.026.046-.04.057-.091l-.006.074c.094-.029.218-.055.357-.075-.091.434-.19.8-.377.342-.051.538-.104 1.097-.129 1.369-.263-1.164-.679-1.778-.77-2.5-.417.497-1.023.367-1.226 1.965-.117.21-.167-.445-.227-.692.065-.163.153-.143.182-.372-.232.419-.738.197-.748 1.307-.34-.483.132-1.025-.296-.825l.044-.341c-.927-1.736-1.279 2.872-2.32.638.07.137.105.2.126.385-1.112-.966-2.21 1.033-3.32-.541-.31-.316-.327.391-.503.931l-.084-.905-.298 1.05c-.44.771-.813-2.213-1.36-.759l.08.609c-.206-.112-.646.368-.618-.334-.02.112-.062.636-.145.318l-.009-.473-.498.819c-.392-.338.051-1.883-.515-1.968C.33 4.627-.06 5.829.02 6.146c.085.022.218.293.226.768l-.195.248c-.034 1.398-.19 2.83.299 3.799l.337-.858.111.677-.285.046c.163.635.265.069.378-.318.028.36.077.611.146.744l.323-1.339c.045.546-.142 1.086.084 1.385.151-.621-.157-1.224.097-1.633.166.632.124 1.15.309.605.03.359-.008.589-.082.748.166-.434.447-.188.526-.933.178.782.567-.211.568 1.111.05-.316.284-1.041.438-1.099-.259 1.587.583.086.539 1.783.185-1.426.75-.642 1.104-1.437-.018.113-.053.343-.088.271.213.115.285.546.426.809-.003-1.176.315-1.456.47-2.188.287 1.125-.117 1.386-.007 2.472-.039-.952.419-.966.309-1.757.217.694.179.335.309 1.306-.01-1.471.176-.256.31-1.164.307.714.117 1.374.414.916.162.446-.099.976-.099.976zm7.281-2.874c0 .009.001.014.001.018-.063.022-.115.043-.149.056.03-.016.072-.037.148-.074zm.617-.046c-.077-.028-.172-.029-.271-.019-.038-.289-.032-.59.03-.578-.021.197.133.357.241.597zm-1.629-5.766c.09-.124.131.04.153.212-.044.017-.096.048-.162.109-.002.031-.004.068-.006.104 0-.161.003-.312.015-.425z"></path><path d="M13.144 4.513c-.013.02-.019.055-.036.063.023.073.046.135.067.187.007-.091.014-.18.02-.267l-.051.017z"></path><path d="m68.993 3.613-.012-.021c.008.035.016.068.019.123-.004-.045-.005-.068-.007-.102z"></path><path d="m23.504 10.196-.017-.214-.04.191z"></path><path d="M72.097 6.793c-.002.074.003.152.021.221.003-.056-.008-.134-.021-.221z"></path><path d="m73.505 7.148.166.322c-.067-.179-.121-.267-.166-.322z"></path><path d="M74.55 7.692c.028-.149.048-.256.067-.356l-.002-.005-.065.361z"></path><path d="M57.015 7.687c-.015.003-.03.015-.043.037-.099.163-.032.098.043-.037z"></path><path d="M62.287 5.783c-.061.151-.12.299-.181.393.092.067.164.087.181-.393z"></path><path d="M51.201 8.797v-.015c-.013.004-.023.001-.036.002l.036.013z"></path><path d="M61.862 6.151c.089.172.168.139.244.024-.075-.059-.163-.149-.244-.024z"></path><path d="m79.191 8.79.046.043c.009-.055.02-.1.03-.133l-.076.09z"></path><path d="m79.268 8.7.075-.088c-.027-.005-.051-.002-.075.088z"></path><path d="m79.502 8.423-.159.189c.042.009.089.043.159-.189z"></path><path d="m77.825 8.168-.065.3c.018-.061.04-.158.065-.3z"></path><path d="M77.375 8.184c.094.086.157.688.332.521l.053-.237c-.141.437-.205-.778-.385-.284z"></path><path d="m76.073 4.147.346.293c-.02-.333-.047-.781.138-.83-.346-1.034-.002.73-.484.537z"></path><path d="M74.95 3.54c.226-.126.058-.47.092-.65-.169.278-.209.348-.092.65z"></path><path d="m66.36 2.741.063-.764c-.165.099-.018.297-.063.764z"></path><path d="m64.54 6.641.129.481.103-.699z"></path><path d="m63.803 1.142.074-.107-.278.269z"></path><path d="m49.296 1.462.083.942c.1-.173.084-1.235-.083-.942z"></path><path d="M43.139 2.726c-.094-.468-.286-.761-.366-.291.142.056.302.417.366.291z"></path><path d="m24.566 2.517.099-.325-.212.28z"></path></g> </svg>',
							itemContent = '<span class="qodef-menu-item-text">' + itemText + '</span><span class="qodef-menu-item-wave">' + itemIcon + '</span>';

						$item.empty().append( itemContent );
					}
				);
			}
		}
	};

	qodef.qodefSocialMenu = qodefSocialMenu;

	var qodefTextualLinks = {
		init: function () {
			var $items = $( '#qodef-page-comments-list .qodef-comment-item .qodef-e-links a' );

			if ( $items.length ) {
				$items.each(
					function () {
						var $item       = $( this ),
							itemText    = $item.text(),
							itemIcon    = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="80.746px" height="12.084px" viewBox="0 0 80.746 12.084" preserveAspectRatio="none" enable-background="new 0 0 80.746 12.084" xml:space="preserve"> <g fill="currentColor"><path d="M80.635 8.387c.091-.245.177-.826.041-.731l-.268.962.227-.231z"></path><path d="M80.201 6.451c-.224.45-.529 1.257-.605 2.169.304-.917.264-.521.614-1.613.137-.095.143.347.056.702.088-.243.138.244.315-.357-.006-.782-.194-.843-.508-.252-.003-.222.085-.471.128-.649z"></path><path d="m68.916 3.47.065.123c-.015-.067-.038-.105-.065-.123z"></path><path d="M61.732 2.557c.056-.021.081-.12.086-.21-.052.063-.096.123-.086.21z"></path><path d="M60.518 1.438c.026.032.049.046.072.068-.027-.091-.054-.142-.072-.068z"></path><path d="m68.916 3.47-.17-.325c-.037.321.081.247.17.325z"></path><path d="M78.241 8.554c.047-.041.094-.127.144-.241-.039.037-.075.067-.112.087-.01.053-.02.099-.032.154z"></path><path d="m72.167 2.939.059.005c.026-.114.057-.247.09-.396l-.149.391z"></path><path d="M74.631 3.075c-.051-.043-.174.791-.239 1.154.073-.341.134-.5.19-.56.021-.158.037-.35.049-.594z"></path><path d="m78.268 5.094.086-.104c-.024.033-.059.062-.086.104z"></path><path d="M70.431 2.593c.007-.125.008-.235.004-.301-.009.104-.009.205-.004.301z"></path><path d="M2.865 11.348c-.001-.061-.002-.098-.003-.15-.012.085-.016.145.003.15z"></path><path d="m.012 7.208.039-.046c.003-.16.005-.316.008-.473l-.047.519z"></path><path d="M58.254.345c.005.008.006.009.01.016.06-.096.026-.08-.01-.016z"></path><path d="M37.548 1.784c.285.736-.311.991.098 1.804-.056-.327.226-1.335-.098-1.804z"></path><path d="M78.2 8.435c-.033.004-.066.006-.097-.007.039.033.069.036.097.007z"></path><path d="M37.646 3.588v.006l.042.077c-.018-.034-.029-.055-.042-.083z"></path><path d="M53.021.901c.014.148.037.261.062.368-.005-.086-.02-.192-.062-.368z"></path><path d="m56.919 2.043-.097-.113c.039.077.07.103.097.113z"></path><path d="M51.038 2.132c-.055-.063-.075-.179-.143-.063.008.043.015.072.024.102.023-.115.056-.172.119-.039z"></path><path d="M48.953 2.223c.016.06.03.111.045.168l.064-.048-.109-.12z"></path><path d="M9.238 10.767c-.056-.235-.095-.496-.127-.753.057.596-.243.821.127.753z"></path><path d="M78.319 8.086c-.047.208-.082.309-.119.349.024-.006.049-.019.073-.034.027-.123.047-.24.046-.315z"></path><path d="m51.165 8.784-.327-.111c.093.078.212.116.327.111z"></path><path d="m24.158 9.73-.068.107c.031.017.056-.01.068-.107z"></path><path d="M49.883 8.837c-.068-.294-.137-.465-.204-.574-.011.066-.024.121-.029.219l.233.355z"></path><path d="M9.11 10.005c0 .003.001.009.001.009s-.001-.006-.001-.009z"></path><path d="M6.987 12.084c.319.013.114-1.09.161-1.728.367-.328.202.809.351 1.371.228-.302.372-1.325.55-1.288.02.182.057.247.024.478.218-.89.741-.07.987-1.187.026.098.041.19.05.274-.07-.554-.1-1.117-.106-1.519.141-.024.232-.709.315.013-.087-.018-.082.275-.113.503l.135-.319c.177 1.035-.188.366-.155 1.136.276-.348.575-1.222.808-.935.092 1.016-.503.36-.168 1.255l-.36-.376c.331 1.596-.214-.104.101 1.604.468.277.486-.534.951-.259.075-.571-.072-.835.003-1.406.59-1.051.625 2.532 1.031 1.151.089-.685.071-1.975.439-1.312l-.057 1.156c.443.091.166-1.667.662-.917-.058.456-.323.399-.25.532.343.893.176-.663.403-.676l.101 1.017c.457-.186.929-.948 1.432-1.161-.011.304-.081.628.058.933.621-.542 1.394.051 2.057.609l.184-.895c.056.006.128.391.078.564.265.317-.022-.559.073-.911.134-.07.215.493.144.763.383-.773 1.118-1.686 1.633-.774l-.071.267c.377.333.276-1.827.657-1.029l-.052.16c.79.329 1.577-.528 2.252.752.02-1.273.795.508.716-1.26.498.843.396 1.167 1.053 1.709.17.069.163-1.119.352-1.318l.073.921.202-.987.229 1.093.172-.251c-.079-.05-.191-.402-.199-.668.265-.44.77.588.813 1.061l.643-.832c.013.372-.095.508-.17.751.303-.969.142.967.419.078-.062-.206-.017-.551-.023-.737.215.545.603.52.871.263l-.006.639c.53.123 1.069-.389 1.651-.422-.231-.279-.268-1.385-.105-1.504l.144.97c.063-.612-.207-.354-.037-1.109.226.096.231 1.097.131 1.424l.238-.358c.037.289-.013.447 0 .819.062-.613.531.942.606-.12l.037.289c.582-.037.82-.393 1.29-.479-.056-.842.145-.669.233-1.36.369.242.804.874 1.217.771.262-.441.031-.72.125-1.229.08.765.492.662.317 1.229.493-.163.63-.201 1.218-.872-.096-.31-.184-.441-.163-.706.106-.135.287.302.298.671l-.024.082c.628-1.204 1.81 2.109 2.259.469l-.025.081.526-.873c.279.113-.12.587.114 1.048.54-1.323 1.012.115 1.473-.772.56 2.233 1.421-.258 2.063 1.148l-.067-.53c.106-.532.19.293.303.407-.042-.412-.185-.468-.116-.764 1.152-.731 2.506.63 3.746 1.036.451.118.098-2.771.73-1.531l-.104.999c.835-1.239 1.837-.069 2.665-1.106-.042.23-.029.527-.115.527.219.711.686.007.663-.58.14.061.056.528.153.824.203.416.427-.938.556-.227.021.115-.042.235-.074.293.106-.354.567.064.418-.761.345.383.616-.395.897.086.138-.936.58.423.588-.892.024 1.356.615 1.069.804.423-.057.413.194.418.131.988.235-.024.444-.28.383-.976.481 1.614.845-1.324 1.145.751.685-.744 1.33-1.251 1.962-1.581-.003 1.354-.701.149-.648 1.568.589-.569.922-1.737 1.524-1.423.157.182-.081.589-.131.82.597-.575 1.161.109 1.691-.622-.001.126-.059.263-.112.366.104-.044.244.2.231-.416l-.103.167c-.171-.895.417-1.862.438-2.334-.18 1.762.532.446.243 2.672.069-.115.156-.406.142-.817.104.12.135.36.029.828.378-.333.247-.987.59-.972-.003.298-.073.413-.11.763.176-.579.355-1.159.644-.906-.02.18.012.414-.074.409.496-.088.868-1.542 1.409-.978-.184 1.293.179.427.187 1.547l.299-.332-.106-.544c.256.018.501-.789.714-.413l-.201.454.486-.194-.263-.435c.275-.567.007-1.418.344-1.094-.073.112.26.023.375.688v.003c.138-.352.281-.721.464-.437.038.36-.079 1.236-.055 1.476.156-.931.61-.236.806-1.228-.062.232-.086.82-.073.94l.134-.756c.11.247.123.365.086.833.354.152-.059-1.423.344-.796-.036.061-.024.175-.099.287.414.335.849-.451 1.226-.063.062 1.131-.355.263-.269 1.218.57-.18 1.24-1.316 1.772-1.001l-.095-.132c.171-1.582.36.816.682.088-.075.112-.145.874-.115.699.356.282.786-.334 1.393-.79l-.101.402c.193.38.564.253.787.456.103-.401.234-.325.199-.924.533 2.381 1.521-1.153 1.991.857-.078-.005-.219.334-.158.344l.588-.311c.026-.695-.029-.427-.092-.978.111-.4.302-.698.44-.683-.299.428-.112 1.108-.046 1.505.004-.213.065-.441.079-.658.159 1.261.196-1.381.506-.508l-.061.359c.168-.168.358-.63.509-.508-.024.805-.201.354-.284 1.008.228-.02.616-1.457.729-.639-.122.21-.26.198-.381.407.113.962.165.727.312.894l-.014-.022.325.468-.064-.266c.533-2.042.614-.312 1.167-1.626-.535 1.242-.156.736-.302 1.634.063.262.172.56.098.808.272-.706.217.607.608-.426-.028.291.186.05.046.773.26-.201.016-.511.084-.872.498-.957.655 1.321 1.359.047.521-.486.756-1.447 1.247-1.863.064.484-.282 1.033-.282 1.033.155.462.333.411.598.116-.084.244-.075.465-.065.8.179-.049.288-1.032.438-.57-.093.315-.229.821-.363 1.131.24-.233.527-.739.778-.965-.034.511-.257.741-.385 1.058.267-.188.671-.356.886-1.14l-.098-.309c.092-.023-.079.69-.166.825-.307.59-.235-.323-.196-.614l.179-.16c.146-1.715-.639.173-.913.026l.33-1.21-.475.971c-.011-.331.057-1.026.235-1.186-.115-.645-.262.406-.335-.303-.004-.109.016-.167.042-.213l-.269.332c.082-.252.104-.876.205-.676-.269-.774-.755.823-.753-.135l.044-.07c-.588.33-.19.896-.738 1.896l.065-2.279-.186.905c-.05-.041-.146-.127-.075-.486-.289.587-.021.4-.223.967-.141-.877-.769.297-.63-1.16-.187.679.178.562-.166 1.008.13-1.564-.356.229-.5-.513.178-.795.351-.343.203-1.087-.32 1.34-.429-.354-.667-.117-.145 1.08-.496.399-.878.721.064-.361-.569-.67-.845-1.1l.029-.181c-.181 1.088-.483.844-.744 1.042.077-.654.146-.908.307-1.187l-.226-.021c-.089.345-.178.522-.335.631l.139-.813c-.306.012-.695.887-1.028.316-.091.764.104 2.153-.343 2.634.023-.415.072-1.123.193-1.284-.039.052-.154.334-.207.152l.225-.684c-.146-.319-.145.574-.277.499.056-.59-.065-.429-.003-.896.041-.055.1.253.174.025-.147-.117-.308-.481-.332-.934-.016.337-.069.795-.191.863-.302.021-.041-.718-.19-1.035-.107.405-.263-.034-.341.849-.087-.012-.069-.425-.084-.666-.187.378-.733.058-.631 1.01l.034.064c-.009.019-.018.019-.028.039h.001H69c-.568.84-1.012-.579-1.541-.237l.021-.296c-.321.314-.68.149-.93.77-.088-.007-.178-.555-.12-.904-.242.203-.284.541-.59.039.258-.508-.056-.461.257-.369-.284-.267-.33-.743-.69.054.146-.754-.18-.964-.333-.742l.185.55c-.165.104-.302.032-.44-.038l.122-.994c-.567-1.236-1.189 2.022-1.58-.025-.187.691.316.503.142 1.314-.274-.146-.521-1.589-.611-1.595-.372-.567-.405 1.444-.798 1.051.043.357.064 1.31-.242 1.634-.275-.143-.309-1.506-.124-1.785.068-.027.099.087.093.207.094-.125.218-.273.115-.664l-.045.354c-.131-.368-.521-.345-.417-.925-.222.331-.104.58.05.771-.354-.535-.568-.028-.934-.378.056.196.103.615.044.61-.538-.443-.251.674-.621.828-.201-.544.093-1.295-.284-.843-.223-.369-.037-.945.058-1.234-.349.684-.632-.455-.828-.582L59.142 0c-.109.17-.198.164-.288.162l.098.713c-.104-.126-.194-.128-.19-.425-.111.466.074 1.185-.144 1.821-.138-.362-.427.386-.472-.56.439.323-.045-.949.33-1.1-.073.112-.161.107-.267-.019-.016-.105.016-.195.045-.249-.422-.848-.198 1.067-.636 1.043.057-.532-.102-1.011-.173-.897.177.012.084.889-.077 1.296-.28-.417-.303.307-.449.257l.167.196c-.055.532-.194.461-.388.628-.019-.415.176-.284.105-.468-.21.937-.494-.975-.791-.34-.143-.357-.022-1-.147-1.242-.332.697-.375-.722-.726-.145.112.714.127.538-.114 1.24l.578-.515-.362 1.048c.175.007.365-.457.472-.337-.172.587-.155.408-.065 1.001-.251-1.069-.467.635-.752-.085l-.016-1.769c-.433-.781-.731.924-1.281.49l.181.304c-.06.705-.334.104-.503.394.004-.593-.111-.806-.194-1.172.019.438-.4-.032-.421 1.151l-.262-.775c-.448-.311-.455 1.697-.88 1.505.108-.646-.096-1.063.174-1.528-.142-.003-.271-.108-.262.301-.094-.367-.365.805-.512.248-.051.263-.05.884-.209.841-.021-.12-.009-.293-.009-.293.009.292-.232.408-.073 1.058-.494-1.829-1.195.185-1.631-1.387-.298.211-.658.417-.934.471.011-.178-.012-.295.044-.235-.407-.535-.162 1.709-.623 1.112-.265-.947.208-.527.054-.884-.148-1.944-.514.288-.859-.837l.065-.117c-.257-.652-.513.76-.885.637 0 0 .009-.174-.013-.295-.2 1.008-.654 1.363-.989 1.659.068-.768.138-.412.03-1.183-.151.12.112 1.241-.189 1.475-.125-.411-.371-.762-.446-1.586l.294-.062c-.21-1.06-.382.059-.548-.118l-.006-.468c-.447.178-.387 1.354-.879 1.299l.071.351c-.198 1.181-.262-.643-.477.239l-.15-1.178c-.16.295-.548 1.179-.849 1.419.124-.887.466-1.357.664-1.891-.175.002-.589.122-.644.71.063-.118.134-.412.215-.234-.158.941-.41 1.415-.758 1.414-.084-2.298-.94-.521-1.309-2.28-.558.89-1.243-.278-1.951-.093.377 1.765-.205.065-.034 1.892-.158.129-.224.104-.247-.015l-.581-1.058c-.157-.524.13-.414.086-.824-.376-.115-.208-.765-.485-1.234.097.651-.061.946-.286.711l.354.823c-.44 1.01-.552-1.505-.997-.505l.121-.587c-.241.356-.975.059-1.124 1.548-.063-.207-.161-.703-.055-.844-.646-.173-1.283 1.669-1.839.802l.014-.451c-.107.139-.141.856-.321.417-.007-.186.014-.45-.043-.473-.051.159-.253.808-.428.559l.095-.514c-.658-.539-.848 1.297-1.338 1.643-.1-1.317-.615-1.708-.871-1.902l-.007-.187c-.724-.107-1.124 1.185-1.744 1.753-.519-1.398-1.432-.491-2.151-1.242.119.231.063 1.027-.044 1.168-.175-.255-.356.946-.425-.263l.057.019c-.207-1.175-.5-.835-.749-.851l.08 1.583c-.819-2.25-1.631.97-2.137-1.063-.126.407-.319.416-.445.822l-.054-.848c-.447-.184-.671-.274-1.189-.033l.065-.613c-.305-.032-.204 2.471-.479 2.541l-.174-1.258c-.525.061-1.13-1.02-1.569.163-.004-.186-.014-.553.067-.609-.249-.018-1.01-.793-.804.938-.082-1.131-.548-.075-.799.442l-.011-.838c-.169 1.082-.158 1.374-.474 1.691-.086-.104-.112-.663.007-.457-.292-.419-.155.805-.504.381l.085-.541c-.275-.046-.235.238-.346.87-.15.346-.529-.177-.616-.929-.008.462-.119 1.087-.293.881-.039-.284.009-.465.033-.553-.488-.54-.617 1.007-.978.205-.022-.276-.051-.414-.082-.495.361.001.653.031.63.094-.046-.77-.344-.89-.177-1.964-.196.592-.522 1.874-.826 1.527-.018-.074-.035-.146-.053-.265l.024-.088c-.069-.073-.124.002-.172.134-.097-.121-.159-.212-.247-.219-.068-.635-.351-.325-.497-.349.058.841-.14.716.076 1.402-.026-.06.021-.103.116-.143.021-.026.046-.04.057-.091l-.006.074c.094-.029.218-.055.357-.075-.091.434-.19.8-.377.342-.051.538-.104 1.097-.129 1.369-.263-1.164-.679-1.778-.77-2.5-.417.497-1.023.367-1.226 1.965-.117.21-.167-.445-.227-.692.065-.163.153-.143.182-.372-.232.419-.738.197-.748 1.307-.34-.483.132-1.025-.296-.825l.044-.341c-.927-1.736-1.279 2.872-2.32.638.07.137.105.2.126.385-1.112-.966-2.21 1.033-3.32-.541-.31-.316-.327.391-.503.931l-.084-.905-.298 1.05c-.44.771-.813-2.213-1.36-.759l.08.609c-.206-.112-.646.368-.618-.334-.02.112-.062.636-.145.318l-.009-.473-.498.819c-.392-.338.051-1.883-.515-1.968C.33 4.627-.06 5.829.02 6.146c.085.022.218.293.226.768l-.195.248c-.034 1.398-.19 2.83.299 3.799l.337-.858.111.677-.285.046c.163.635.265.069.378-.318.028.36.077.611.146.744l.323-1.339c.045.546-.142 1.086.084 1.385.151-.621-.157-1.224.097-1.633.166.632.124 1.15.309.605.03.359-.008.589-.082.748.166-.434.447-.188.526-.933.178.782.567-.211.568 1.111.05-.316.284-1.041.438-1.099-.259 1.587.583.086.539 1.783.185-1.426.75-.642 1.104-1.437-.018.113-.053.343-.088.271.213.115.285.546.426.809-.003-1.176.315-1.456.47-2.188.287 1.125-.117 1.386-.007 2.472-.039-.952.419-.966.309-1.757.217.694.179.335.309 1.306-.01-1.471.176-.256.31-1.164.307.714.117 1.374.414.916.162.446-.099.976-.099.976zm7.281-2.874c0 .009.001.014.001.018-.063.022-.115.043-.149.056.03-.016.072-.037.148-.074zm.617-.046c-.077-.028-.172-.029-.271-.019-.038-.289-.032-.59.03-.578-.021.197.133.357.241.597zm-1.629-5.766c.09-.124.131.04.153.212-.044.017-.096.048-.162.109-.002.031-.004.068-.006.104 0-.161.003-.312.015-.425z"></path><path d="M13.144 4.513c-.013.02-.019.055-.036.063.023.073.046.135.067.187.007-.091.014-.18.02-.267l-.051.017z"></path><path d="m68.993 3.613-.012-.021c.008.035.016.068.019.123-.004-.045-.005-.068-.007-.102z"></path><path d="m23.504 10.196-.017-.214-.04.191z"></path><path d="M72.097 6.793c-.002.074.003.152.021.221.003-.056-.008-.134-.021-.221z"></path><path d="m73.505 7.148.166.322c-.067-.179-.121-.267-.166-.322z"></path><path d="M74.55 7.692c.028-.149.048-.256.067-.356l-.002-.005-.065.361z"></path><path d="M57.015 7.687c-.015.003-.03.015-.043.037-.099.163-.032.098.043-.037z"></path><path d="M62.287 5.783c-.061.151-.12.299-.181.393.092.067.164.087.181-.393z"></path><path d="M51.201 8.797v-.015c-.013.004-.023.001-.036.002l.036.013z"></path><path d="M61.862 6.151c.089.172.168.139.244.024-.075-.059-.163-.149-.244-.024z"></path><path d="m79.191 8.79.046.043c.009-.055.02-.1.03-.133l-.076.09z"></path><path d="m79.268 8.7.075-.088c-.027-.005-.051-.002-.075.088z"></path><path d="m79.502 8.423-.159.189c.042.009.089.043.159-.189z"></path><path d="m77.825 8.168-.065.3c.018-.061.04-.158.065-.3z"></path><path d="M77.375 8.184c.094.086.157.688.332.521l.053-.237c-.141.437-.205-.778-.385-.284z"></path><path d="m76.073 4.147.346.293c-.02-.333-.047-.781.138-.83-.346-1.034-.002.73-.484.537z"></path><path d="M74.95 3.54c.226-.126.058-.47.092-.65-.169.278-.209.348-.092.65z"></path><path d="m66.36 2.741.063-.764c-.165.099-.018.297-.063.764z"></path><path d="m64.54 6.641.129.481.103-.699z"></path><path d="m63.803 1.142.074-.107-.278.269z"></path><path d="m49.296 1.462.083.942c.1-.173.084-1.235-.083-.942z"></path><path d="M43.139 2.726c-.094-.468-.286-.761-.366-.291.142.056.302.417.366.291z"></path><path d="m24.566 2.517.099-.325-.212.28z"></path></g> </svg>',
							itemContent = '<span class="qodef-menu-item-text">' + itemText + '</span><span class="qodef-m-wave">' + itemIcon + '</span><span class="qodef-m-wave-fake">' + itemIcon + '</span>';

						$item.empty().append( itemContent );
					}
				);
			}
		}
	};

	qodef.qodefTextualLinks = qodefTextualLinks;

	if ( typeof Object.assign !== 'function' ) {
		Object.assign = function ( target ) {

			if ( target === null || typeof target === 'undefined' ) {
				throw new TypeError( 'Cannot convert undefined or null to object' );
			}

			target = Object( target );
			for ( var index = 1; index < arguments.length; index++ ) {
				var source = arguments[index];

				if ( source !== null ) {
					for ( var key in source ) {
						if ( Object.prototype.hasOwnProperty.call(
							source,
							key
						) ) {
							target[key] = source[key];
						}
					}
				}
			}

			return target;
		};
	}

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefResizeIframes.init();
		}
	);

	$( window ).resize(
		function () {
			qodefResizeIframes.init();
		}
	);

	$( document ).on(
		'ginevra_trigger_get_new_posts',
		function ( e, $holder ) {
			if ( $holder.hasClass( 'qodef-blog' ) ) {
				qodefReInitMediaElementPostFormats.resize( $holder );
				qodefResizeIframes.resize( $holder );
			}
		}
	);

	/**
	 * Re init media element post formats (audio, video)
	 */
	var qodefReInitMediaElementPostFormats = {
		init: function () {
			var $holder = $( '.qodef-blog' );

			if ( $holder.length ) {
				qodefReInitMediaElementPostFormats.resize( $holder );
			}
		},
		resize: function ( $holder ) {
			var $mediaElement = $holder.find( '.wp-video-shortcode, .wp-audio-shortcode' ).not( '.mejs-container' );

			if ( $mediaElement.length ) {
				$mediaElement.each(
					function () {
						var $thisMediaElement = $( this );

						if ( typeof $thisMediaElement.mediaelementplayer === 'function' ) {
							$thisMediaElement.mediaelementplayer(
								{
									videoWidth: '100%',
									videoHeight: '56.5%',
								}
							);
						}
					}
				);
			}
		}
	};

	qodef.qodefReInitMediaElementPostFormats = qodefReInitMediaElementPostFormats;

	/**
	 * Resize oembed iframes
	 */
	var qodefResizeIframes = {
		init: function () {
			var $holder = $( '.qodef-blog' );

			if ( $holder.length ) {
				qodefResizeIframes.resize( $holder );
			}
		},
		resize: function ( $holder ) {
			var $iframe = $holder.find( '.qodef-e-media iframe' );

			if ( $iframe.length ) {
				$iframe.each(
					function () {
						var $thisIframe = $( this ),
							width       = $thisIframe.attr( 'width' ),
							height      = $thisIframe.attr( 'height' ),
							newHeight   = $thisIframe.width() / width * height; // rendered width divided by aspect ratio

						$thisIframe.css( 'height', newHeight );
					}
				);
			}
		}
	};

	qodef.qodefResizeIframes = qodefResizeIframes;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefFilter.init();
		}
	);

	$( document ).on(
		'ginevra_trigger_get_new_posts',
		function ( e, $holder ) {
			if ( $holder.hasClass( 'qodef-filter--on' ) ) {
				$holder.removeClass( 'qodef--filter-loading' );
			}
		}
	);

	/*
	 **	Init filter functionality
	 */
	var qodefFilter = {
		customListQuery: {},
		init: function ( settings ) {
			this.holder = $( '.qodef-filter--on' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $holder      = $( this ),
							$filterItems = $holder.find( '.qodef-m-filter-item' ),
                        	customListQuery = qodefFilter.checkCustomListQuery( $holder.data( 'options' ) );

                        qodefFilter.clickEvent( $holder, $filterItems, customListQuery );
					}
				);
			}
		},
		checkCustomListQuery: function ( options ) {
			if ( typeof options.additional_query_args !== 'undefined' && typeof options.additional_query_args.tax_query !== 'undefined' ) {
                return options.additional_query_args.tax_query;
			}
		},
		clickEvent: function ( $holder, $filterItems, customListQuery ) {
			$filterItems.on(
				'click',
				function ( e ) {
					e.preventDefault();

					var $thisItem = $( this );

					if ( ! $thisItem.hasClass( 'qodef--active' ) ) {
						$holder.addClass( 'qodef--filter-loading' );
						$filterItems.removeClass( 'qodef--active' );
						$thisItem.addClass( 'qodef--active' );

						qodefFilter.setVisibility( $holder, $thisItem, customListQuery );
					}
				}
			);
		},
		setVisibility: function ( $holder, $item, customListQuery) {
			var filterTaxonomy  = $item.data( 'taxonomy' ),
				filterValue     = $item.data( 'filter' ),
				isShowAllFilter = filterValue === '*',
				options         = $holder.data( 'options' ),
				taxQueryOptions = {};

			if ( ! isShowAllFilter ) {
				taxQueryOptions = {
					0: {
						taxonomy: filterTaxonomy,
						field: typeof filterValue === 'number' ? 'term_id' : 'slug',
						terms: filterValue,
					},
				};
			} else {
                taxQueryOptions = customListQuery;
            }

			options.additional_query_args = {
				tax_query: taxQueryOptions,
			};

			qodef.body.trigger(
				'ginevra_trigger_load_more',
				[$holder, 1]
			);
		},
		isMasonryLayout: function ( $holder ) {
			return $holder.hasClass( 'qodef-layout--masonry' );
		},
		hasLoadMore: function ( $holder ) {
			return $holder.hasClass( 'qodef-pagination-type--load-more' );
		}
	};

	qodef.qodefFilter = qodefFilter;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefJustifiedGallery.init();
		}
	);

	$( document ).on(
		'ginevra_trigger_get_new_posts',
		function () {
			qodefJustifiedGallery.init();
		}
	);

	/**
	 * Init justified gallery functionality
	 */
	var qodefJustifiedGallery = {
		init: function () {
			var $holder = $( '.qodef-layout--justified-gallery' );

			if ( $holder.length ) {
				$holder.each(
					function () {
						qodefJustifiedGallery.setJustifyGallery( $( this ) );
					}
				);
			}
		},
		setJustifyGallery: function ( $holder ) {
			var galleryOptions  = $holder.data( 'options' ),
				$galleryInner   = $holder.children( '.qodef-grid-inner' ),
				rowHeight       = typeof galleryOptions.justified_gallery_row_height !== 'undefined' && galleryOptions.justified_gallery_row_height !== '' ? galleryOptions.justified_gallery_row_height : 150,
				maxRowHeight    = typeof galleryOptions.justified_gallery_row_height_max !== 'undefined' && galleryOptions.justified_gallery_row_height_max !== '' ? galleryOptions.justified_gallery_row_height_max : false,
				margin          = typeof galleryOptions.space_value !== 'undefined' ? galleryOptions.space_value * 2 : 0,
				justifyTreshold = typeof galleryOptions.justified_gallery_treshold !== 'undefined' && galleryOptions.justified_gallery_treshold !== '' ? galleryOptions.justified_gallery_treshold : 0.75;

			qodef.qodefWaitForImages.check(
				$galleryInner,
				function () {
					if ( typeof $galleryInner.justifiedGallery === 'function' ) {
						$galleryInner.justifiedGallery(
							{
								captions: false,
								rowHeight: rowHeight,
								maxRowHeight: maxRowHeight,
								margins: margin,
								border: 0,
								lastRow: 'nojustify',
								justifyThreshold: justifyTreshold,
								selector: '.qodef-grid-item'
							}
						).on(
							'jg.complete jg.rowflush',
							function () {
								var $gal     = $( this ),
									deducted = false;

								$gal.find( '.qodef-grid-item' ).addClass( 'show' ).each(
									function () {
										var $thisItem = $( this );

										$thisItem.height( Math.round( $thisItem.height() ) );

										if ( ! deducted && $thisItem.width() === 0 ) {
											$gal.height( $gal.height() - $thisItem.height() - margin );

											deducted = true;
										}
									}
								);
							}
						);
					}

					$holder.addClass( 'qodef--justified-gallery-init' );
				}
			);
		}
	};

	qodef.qodefJustifiedGallery = qodefJustifiedGallery;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefMasonryLayout.init();
		}
	);

	$( window ).resize(
		function () {
			qodefMasonryLayout.reInit();
		}
	);

	$( document ).on(
		'ginevra_trigger_get_new_posts',
		function ( e, $holder ) {
			if ( $holder.hasClass( 'qodef-layout--masonry' ) ) {
				qodefMasonryLayout.init();
			}
		}
	);

	/**
	 * Init masonry layout
	 */
	var qodefMasonryLayout = {
		init: function ( settings ) {
			this.holder = $( '.qodef-layout--masonry' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						qodefMasonryLayout.createMasonry( $( this ) );
					}
				);
			}
		},
		reInit: function ( settings ) {
			this.holder = $( '.qodef-layout--masonry' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $masonry = $( this ).find( '.qodef-grid-inner' );

						if ( typeof $masonry.isotope === 'function' ) {
							$masonry.isotope( 'layout' );
						}
					}
				);
			}
		},
		createMasonry: function ( $holder ) {
			var $masonry     = $holder.find( '.qodef-grid-inner' ),
				$masonryItem = $masonry.find( '.qodef-grid-item' );

			qodef.qodefWaitForImages.check(
				$masonry,
				function () {
					if ( typeof $masonry.isotope === 'function' ) {
						$masonry.isotope(
							{
								layoutMode: 'packery',
								itemSelector: '.qodef-grid-item',
								percentPosition: true,
								masonry: {
									columnWidth: '.qodef-grid-masonry-sizer',
									gutter: '.qodef-grid-masonry-gutter'
								}
							}
						);

						if ( $holder.hasClass( 'qodef-items--fixed' ) ) {
							var size = qodefMasonryLayout.getFixedImageSize( $masonry, $masonryItem );

							qodefMasonryLayout.setFixedImageProportionSize( $masonry, $masonryItem, size );
						}

						$masonry.isotope( 'layout' );
					}

					$masonry.addClass( 'qodef--masonry-init' );
				}
			);
		},
		getFixedImageSize: function ( $holder, $item ) {
			var $squareItem = $holder.find( '.qodef-item--square' );

			if ( $squareItem.length ) {
				var $squareItemImage      = $squareItem.find( 'img' ),
					squareItemImageWidth  = $squareItemImage.width(),
					squareItemImageHeight = $squareItemImage.height();

				if ( squareItemImageWidth !== squareItemImageHeight ) {
					return squareItemImageHeight;
				} else {
					return squareItemImageWidth;
				}
			} else {
				var size    = $holder.find( '.qodef-grid-masonry-sizer' ).width(),
					padding = parseInt( $item.css( 'paddingLeft' ), 10 );

				return (size - 2 * padding); // remove item side padding to get real item size
			}
		},
		setFixedImageProportionSize: function ( $holder, $item, size ) {
			var padding         = parseInt( $item.css( 'paddingLeft' ), 10 ),
				$squareItem     = $holder.find( '.qodef-item--square' ),
				$landscapeItem  = $holder.find( '.qodef-item--landscape' ),
				$portraitItem   = $holder.find( '.qodef-item--portrait' ),
				$hugeSquareItem = $holder.find( '.qodef-item--huge-square' ),
				isMobileScreen  = qodef.windowWidth <= 680;

			$item.css( 'height', size );

			if ( $landscapeItem.length ) {
				$landscapeItem.css( 'height', Math.round( size / 2 ) );
			}

			if ( $portraitItem.length ) {
				$portraitItem.css( 'height', Math.round( 2 * (size + padding) ) );
			}

			if ( ! isMobileScreen ) {

				if ( $landscapeItem.length ) {
					$landscapeItem.css( 'height', size );
				}

				if ( $hugeSquareItem.length ) {
					$hugeSquareItem.css( 'height', Math.round( 2 * (size + padding) ) );
				}
			}
		}
	};

	qodef.qodefMasonryLayout = qodefMasonryLayout;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefMobileHeader.init();
		}
	);

	/*
	 **	Init mobile header functionality
	 */
	var qodefMobileHeader = {
		init: function () {
			var $holder = $( '#qodef-page-mobile-header' );

			if ( $holder.length ) {
				qodefMobileHeader.initMobileHeaderOpener( $holder );
				qodefMobileHeader.initDropDownMobileMenu();
			}
		},
		initMobileHeaderOpener: function ( $holder ) {
			var $opener = $holder.find( '.qodef-mobile-header-opener' );

			if ( $opener.length ) {
				var $navigation = $holder.find( '.qodef-mobile-header-navigation' );

				$opener.on(
					'tap click',
					function ( e ) {
						e.preventDefault();

						if ( $navigation.is( ':visible' ) ) {
							$navigation.slideUp( 450 );
							$opener.removeClass( 'qodef--opened' );
						} else {
							$navigation.slideDown( 450 );
							$opener.addClass( 'qodef--opened' );
						}
					}
				);
			}
		},
		initDropDownMobileMenu: function () {
			// if menu item has child elements, select arrow and select first anchor if hide link option is set
			var $dropdownOpener = $('.qodef-mobile-header-navigation .menu-item-has-children > .qodef-menu-item-arrow, .qodef-mobile-header-navigation .menu-item-has-children.qodef--hide-link > a');

			if ( $dropdownOpener.length ) {
				$dropdownOpener.each(
					function () {
						var $thisItem = $( this );

						$thisItem.on(
							'tap click',
							function ( e ) {
								e.preventDefault();

								var $thisItemParent                 = $thisItem.parent(),
									$thisItemParentSiblingsWithDrop = $thisItemParent.siblings( '.menu-item-has-children' );

								if ( $thisItemParent.hasClass( 'menu-item-has-children' ) ) {
									var $submenu = $thisItemParent.find( 'ul.sub-menu' ).first();

									if ( $submenu.is( ':visible' ) ) {
										$submenu.slideUp( 450 );
										$thisItemParent.removeClass( 'qodef--opened' );
									} else {
										$thisItemParent.addClass( 'qodef--opened' );

										if ( $thisItemParentSiblingsWithDrop.length === 0 ) {
											$thisItemParent.find( '.sub-menu' ).slideUp(
												400,
												function () {
													$submenu.slideDown( 400 );
												}
											);
										} else {
											$thisItemParent.siblings().removeClass( 'qodef--opened' ).find( '.sub-menu' ).slideUp(
												400,
												function () {
													$submenu.slideDown( 400 );
												}
											);
										}
									}
								}
							}
						);
					}
				);
			}
		}
	};

})( jQuery );

(function ( $ ) {

	$( document ).ready(
		function () {
			qodefDefaultNavMenu.init();
		}
	);

	var qodefDefaultNavMenu = {
		init: function () {
			var $menuItems = $( '.qodef-header-navigation.qodef-header-navigation-initial > ul > li.qodef-menu-item--narrow.menu-item-has-children' );

			if ( $menuItems.length ) {
				$menuItems.each(
					function () {
						var thisItem          = $( this ),
							menuItemPosition  = thisItem.offset().left,
							dropdownMenuItem  = thisItem.find( ' > ul' ),
							dropdownMenuWidth = dropdownMenuItem.outerWidth(),
							menuItemFromLeft  = $( window ).width() - menuItemPosition;

						var dropDownMenuFromLeft;

						if ( thisItem.find( 'li.menu-item-has-children' ).length > 0 ) {
							dropDownMenuFromLeft = menuItemFromLeft - dropdownMenuWidth;
						}

						dropdownMenuItem.removeClass( 'qodef-drop-down--right' );

						if ( menuItemFromLeft < dropdownMenuWidth || dropDownMenuFromLeft < dropdownMenuWidth ) {
							dropdownMenuItem.addClass( 'qodef-drop-down--right' );
						}
					}
				);
			}
		}
	};

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefPagination.init();
		}
	);

	$( window ).scroll(
		function () {
			qodefPagination.scroll();
		}
	);

	$( document ).on(
		'ginevra_trigger_load_more',
		function ( e, $holder, nextPage ) {
			qodefPagination.triggerLoadMore( $holder, nextPage );
		}
	);

	/*
	 **	Init pagination functionality
	 */
	var qodefPagination = {
		init: function ( settings ) {
			this.holder = $( '.qodef-pagination--on' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $holder = $( this );

						qodefPagination.initPaginationType( $holder );
					}
				);
			}
		},
		scroll: function ( settings ) {
			this.holder = $( '.qodef-pagination--on' );

			// Allow overriding the default config
			$.extend( this.holder, settings );

			if ( this.holder.length ) {
				this.holder.each(
					function () {
						var $holder = $( this );

						if ( $holder.hasClass( 'qodef-pagination-type--infinite-scroll' ) ) {
							qodefPagination.initInfiniteScroll( $holder );
						}
					}
				);
			}
		},
		initPaginationType: function ( $holder ) {
			if ( $holder.hasClass( 'qodef-pagination-type--standard' ) ) {
				qodefPagination.initStandard( $holder );
			} else if ( $holder.hasClass( 'qodef-pagination-type--load-more' ) ) {
				qodefPagination.initLoadMore( $holder );
			} else if ( $holder.hasClass( 'qodef-pagination-type--infinite-scroll' ) ) {
				qodefPagination.initInfiniteScroll( $holder );
			}
		},
		initStandard: function ( $holder, nextPage ) {
			var $paginationItems = $holder.find( '.qodef-m-pagination-items' );

			if ( $paginationItems.length ) {
				var options      = $holder.data( 'options' ),
					current_page = typeof nextPage !== 'undefined' && nextPage !== '' ? parseInt( nextPage, 10 ) : 1;

				qodefPagination.changeStandardState( $holder, options.max_pages_num, current_page );

				$paginationItems.children().each(
					function () {
						var $thisItem = $( this );

						$thisItem.on(
							'click',
							function ( e ) {
								e.preventDefault();

								if ( ! $thisItem.hasClass( 'qodef--active' ) ) {
									qodefPagination.getNewPosts( $holder, $thisItem.data( 'paged' ) );
								}
							}
						);
					}
				);
			}
		},
		changeStandardState: function ( $holder, maxPagesNum, nextPage ) {
			if ( $holder.hasClass( 'qodef-pagination-type--standard' ) ) {
				var $paginationNav = $holder.find( '.qodef-m-pagination-items' ),
					$numericItem   = $paginationNav.children( '.qodef--number' ),
					$prevItem      = $paginationNav.children( '.qodef--prev' ),
					$nextItem      = $paginationNav.children( '.qodef--next' );

				qodefPagination.standardPaginationVisibility( $paginationNav, maxPagesNum );

				$numericItem.removeClass( 'qodef--active' ).eq( nextPage - 1 ).addClass( 'qodef--active' );

				$prevItem.data( 'paged', nextPage - 1 );

				if ( nextPage > 1 ) {
					$prevItem.show();
					$prevItem.next().removeClass( 'qodef-prev--hidden' );
				} else {
					$prevItem.hide();
					$prevItem.next().addClass( 'qodef-prev--hidden' );
				}

				$nextItem.data( 'paged', nextPage + 1 );

				if ( nextPage === maxPagesNum ) {
					$nextItem.hide();
				} else {
					$nextItem.show();
				}
			}
		},
		standardPaginationVisibility: function ( $paginationNav, maxPagesNum ) {
			if ( maxPagesNum === 1 ) {
				$paginationNav.hide();
			} else if ( maxPagesNum > 1 && ! $paginationNav.is( ':visible' ) ) {
				$paginationNav.show();
			}
		},
		changeStandardHtml: function ( $holder, maxPagesNum, nextPage, $pagination_html ) {
			if ( $holder.hasClass( 'qodef-pagination-type--standard' ) ) {
				var $paginationNav     = $holder.find( '.qodef-m-pagination' ),
					$paginationSpinner = $holder.find( '.qodef-m-pagination-spinner' );

				qodefPagination.standardPaginationVisibility(
					$paginationNav,
					maxPagesNum
				);

				$paginationNav.remove();
				$paginationSpinner.remove();

				$holder.append( $pagination_html );
				qodefPagination.initStandard( $holder, nextPage );
			}
		},
		triggerStandardScrollAnimation: function ( $holder ) {
			if ( $holder.hasClass( 'qodef-pagination-type--standard' ) ) {
				$( 'html, body' ).animate(
					{
						scrollTop: $holder.offset().top - 100
					},
					500
				);
			}
		},
		initLoadMore: function ( $holder ) {
			var $loadMoreButton = $holder.find( '.qodef-load-more-button' );

			$loadMoreButton.on(
				'click',
				function ( e ) {
					e.preventDefault();

					qodefPagination.getNewPosts( $holder );
				}
			);
		},
		triggerLoadMore: function ( $holder, nextPage ) {
			qodefPagination.getNewPosts( $holder, nextPage );
		},
		loadMoreButtonVisibility: function ( $holder, options ) {
			if ( $holder.hasClass( 'qodef-pagination-type--load-more' ) ) {

				if ( options.next_page > options.max_pages_num || options.max_pages_num === 1 ) {
					$holder.find( '.qodef-load-more-button' ).hide();
				} else if ( options.max_pages_num > 1 && options.next_page <= options.max_pages_num ) {
					$holder.find( '.qodef-load-more-button' ).show();
				}
			}
		},
		initInfiniteScroll: function ( $holder ) {
			var holderEndPosition = $holder.outerHeight() + $holder.offset().top,
				scrollPosition    = qodef.scroll + qodef.windowHeight,
				options           = $holder.data( 'options' );

			if ( ! $holder.hasClass( 'qodef--loading' ) && scrollPosition > holderEndPosition && options.max_pages_num >= options.next_page ) {
				qodefPagination.getNewPosts( $holder );
			}
		},
		getNewPosts: function ( $holder, nextPage ) {
			$holder.addClass( 'qodef--loading' );

			var $itemsHolder = $holder.children( '.qodef-grid-inner' );
			var options      = $holder.data( 'options' );

			qodefPagination.setNextPageValue( options, nextPage, false );

			$.ajax(
				{
					type: 'GET',
					url: qodefGlobal.vars.restUrl + qodefGlobal.vars.paginationRestRoute,
					data: {
						options: options
					},
					beforeSend: function ( request ) {
						request.setRequestHeader(
							'X-WP-Nonce',
							qodefGlobal.vars.restNonce
						);
					},
					success: function ( response ) {

						if ( response.status === 'success' ) {
							// Override max page numbers options
							if ( options.max_pages_num !== response.data.max_pages_num ) {
								options.max_pages_num = response.data.max_pages_num;
							}

							qodefPagination.setNextPageValue( options, nextPage, true );
							qodefPagination.changeStandardHtml( $holder, options.max_pages_num, nextPage, response.data.pagination_html );

							qodefPagination.addPosts( $itemsHolder, response.data.html, nextPage );
							qodefPagination.reInitMasonryPosts( $holder, $itemsHolder );

							setTimeout(
								function () {
									qodef.body.trigger(
										'ginevra_trigger_get_new_posts',
										[$holder, response.data, nextPage]
									);
								},
								300
							); // 300ms is set in order to be after the masonry script initialize

							qodefPagination.triggerStandardScrollAnimation( $holder );
							qodefPagination.loadMoreButtonVisibility( $holder, options );
						} else {
							console.log( response.message );
						}
					},
					complete: function () {
						$holder.removeClass( 'qodef--loading' );
					}
				}
			);
		},
		setNextPageValue: function ( options, nextPage, ajaxTrigger ) {
			if ( typeof nextPage !== 'undefined' && nextPage !== '' && ! ajaxTrigger ) {
				options.next_page = nextPage;
			} else if ( ajaxTrigger ) {
				options.next_page = parseInt( options.next_page, 10 ) + 1;
			}
		},
		addPosts: function ( $itemsHolder, newItems, nextPage ) {
			if ( typeof nextPage !== 'undefined' && nextPage !== '' ) {
				$itemsHolder.html( newItems );
			} else {
				$itemsHolder.append( newItems );
			}
		},
		reInitMasonryPosts: function ( $holder, $itemsHolder ) {
			if ( $holder.hasClass( 'qodef-layout--masonry' ) ) {
				$itemsHolder.isotope( 'reloadItems' ).isotope( { sortBy: 'original-order' } );

				setTimeout(
					function () {
						$itemsHolder.isotope( 'layout' );
					},
					200
				);
			}
		}
	};

	qodef.qodefPagination = qodefPagination;

})( jQuery );

(function ( $ ) {
	'use strict';

	$( document ).ready(
		function () {
			qodefWooQuantityButtons.init();
			qodefWooMagnificPopup.init();
			qodefWooProductSearch.init();
			qodefWooButtons.init();
		}
	);

	$( window ).on(
		'load',
		function () {
			qodefWooSelect2.init();
		}
	);

	var qodefWooSelect2 = {
		init: function ( settings ) {
			this.holder = [];
			this.holder.push(
				{
					holder: $( '#qodef-woo-page .woocommerce-ordering select' ),
					options: {
						minimumResultsForSearch: Infinity
					}
				}
			);
			this.holder.push(
				{
					holder: $( '.variations select:not(.yith_wccl_custom):not([data-type="colorpicker"]):not([data-type="image"]):not([data-type="label"])' ),
					options: {
						minimumResultsForSearch: Infinity
					},
				}
			);
			this.holder.push(
				{
					holder: $( '#qodef-woo-page #calc_shipping_country' ),
					options: {}
				}
			);
			this.holder.push(
				{
					holder: $( '#qodef-woo-page .shipping select#calc_shipping_state' ),
					options: {}
				}
			);
			this.holder.push(
				{
					holder: $( '.widget.widget_archive select' ),
					options: {}
				}
			);
			this.holder.push(
				{
					holder: $( '.widget .wp-block-group .wp-block-archives-dropdown select' ),
				}
			);
			this.holder.push(
				{
					holder: $( '.widget.widget_categories select' ),
					options: {}
				}
			);
			this.holder.push(
				{
					holder: $( '.widget .wp-block-group .wp-block-categories-dropdown select' ),
					options: {}
				}
			);
			this.holder.push(
				{
					holder: $( '.widget.widget_text select' ),
					options: {}
				}
			);

			// Allow overriding the default config
			$.extend(
				this.holder,
				settings
			);

			if ( typeof this.holder === 'object' ) {
				$.each(
					this.holder,
					function ( key, value ) {
						qodefWooSelect2.createSelect2(
							value.holder,
							value.options
						);
					}
				);
			}
		},
		createSelect2: function ( $holder, options ) {
			if ( typeof $holder.select2 === 'function' ) {
				$holder.select2( options );
			}
		}
	};

	var qodefWooQuantityButtons = {
		init: function () {
			$( document ).on(
				'click',
				'.qodef-quantity-minus, .qodef-quantity-plus',
				function ( e ) {
					e.stopPropagation();

					var $button     = $( this ),
						$inputField = $button.siblings( '.qodef-quantity-input' ),
						step        = parseFloat( $inputField.data( 'step' ) ),
						max         = parseFloat( $inputField.data( 'max' ) ),
						min         = parseFloat( $inputField.data( 'min' ) ),
						minus       = false,
						inputValue  = typeof Number.isNaN === 'function' && Number.isNaN( parseFloat( $inputField.val() ) ) ? min : parseFloat( $inputField.val() ),
						newInputValue;

					if ( $button.hasClass( 'qodef-quantity-minus' ) ) {
						minus = true;
					}

					if ( minus ) {
						newInputValue = inputValue - step;
						if ( newInputValue >= min ) {
							$inputField.val( newInputValue );
						} else {
							$inputField.val( min );
						}
					} else {
						newInputValue = inputValue + step;
						if ( max === undefined ) {
							$inputField.val( newInputValue );
						} else {
							if ( newInputValue >= max ) {
								$inputField.val( max );
							} else {
								$inputField.val( newInputValue );
							}
						}
					}

					$inputField.trigger( 'change' );
				}
			);
		}
	};

	var qodefWooMagnificPopup = {
		init: function () {
			if ( typeof qodef.qodefMagnificPopup === 'object' ) {
				var $holder = $( '.qodef--single.qodef-magnific-popup.qodef-popup-gallery .woocommerce-product-gallery__image' );

				if ( $holder.length ) {
					$holder.each(
						function () {
							$( this ).children( 'a' ).attr(
								'data-type',
								'image'
							).addClass( 'qodef-popup-item' );
						}
					);

					qodef.qodefMagnificPopup.init();
				}
			}
		}
	};

	qodef.qodefWooMagnificPopup = qodefWooMagnificPopup;

	// temporary solution, we have asked for filter in product search block widget
	var qodefWooProductSearch = {
		init: function () {
			var $holder = $( '.widget .wc-block-product-search' );

			if ( $holder.length ) {
				$holder.each(
					function () {
						var $label       = $( this ).find( '.wc-block-product-search__label' ),
							$holderInner = $( this ).find( '.wc-block-product-search__fields' ),
							$field       = $( this ).find( '.wc-block-product-search__field' ),
							$button      = $( this ).find( '.wc-block-product-search__button' );

						if ( $label.length ) {
							$label.removeClass().addClass( 'qodef-search-form-label' );
						}

						if ( $holderInner.length ) {
							$holderInner.removeClass().addClass( 'qodef-search-form-inner' );
						}

						if ( $field.length ) {
							$field.removeClass().addClass( 'qodef-search-form-field' );
						}

						if ( $button.length ) {
							$button.removeClass().addClass( 'qodef-search-form-button qodef--button-inside qodef--has-icon' );
							$button.html( '<svg class="qodef-svg--search" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="20" height="20" viewBox="0 0 20 20"><path d="M18.869 19.162l-5.943-6.484c1.339-1.401 2.075-3.233 2.075-5.178 0-2.003-0.78-3.887-2.197-5.303s-3.3-2.197-5.303-2.197-3.887 0.78-5.303 2.197-2.197 3.3-2.197 5.303 0.78 3.887 2.197 5.303 3.3 2.197 5.303 2.197c1.726 0 3.362-0.579 4.688-1.645l5.943 6.483c0.099 0.108 0.233 0.162 0.369 0.162 0.121 0 0.242-0.043 0.338-0.131 0.204-0.187 0.217-0.503 0.031-0.706zM1 7.5c0-3.584 2.916-6.5 6.5-6.5s6.5 2.916 6.5 6.5-2.916 6.5-6.5 6.5-6.5-2.916-6.5-6.5z"></path></svg>' );
						}
					}
				);
			}
		}
	};

	var qodefWooButtons = {
		init: function () {
			var $button = $( '.price_slider_amount .button' );

			if ( $button.length ) {
				$button.each(
					function () {
						var $thisButton   = $( this ),
							buttonText    = $thisButton.text(),
							buttonIcon    = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="80.746px" height="12.084px" viewBox="0 0 80.746 12.084" preserveAspectRatio="none" enable-background="new 0 0 80.746 12.084" xml:space="preserve"> <g fill="currentColor"><path d="M80.635 8.387c.091-.245.177-.826.041-.731l-.268.962.227-.231z"></path><path d="M80.201 6.451c-.224.45-.529 1.257-.605 2.169.304-.917.264-.521.614-1.613.137-.095.143.347.056.702.088-.243.138.244.315-.357-.006-.782-.194-.843-.508-.252-.003-.222.085-.471.128-.649z"></path><path d="m68.916 3.47.065.123c-.015-.067-.038-.105-.065-.123z"></path><path d="M61.732 2.557c.056-.021.081-.12.086-.21-.052.063-.096.123-.086.21z"></path><path d="M60.518 1.438c.026.032.049.046.072.068-.027-.091-.054-.142-.072-.068z"></path><path d="m68.916 3.47-.17-.325c-.037.321.081.247.17.325z"></path><path d="M78.241 8.554c.047-.041.094-.127.144-.241-.039.037-.075.067-.112.087-.01.053-.02.099-.032.154z"></path><path d="m72.167 2.939.059.005c.026-.114.057-.247.09-.396l-.149.391z"></path><path d="M74.631 3.075c-.051-.043-.174.791-.239 1.154.073-.341.134-.5.19-.56.021-.158.037-.35.049-.594z"></path><path d="m78.268 5.094.086-.104c-.024.033-.059.062-.086.104z"></path><path d="M70.431 2.593c.007-.125.008-.235.004-.301-.009.104-.009.205-.004.301z"></path><path d="M2.865 11.348c-.001-.061-.002-.098-.003-.15-.012.085-.016.145.003.15z"></path><path d="m.012 7.208.039-.046c.003-.16.005-.316.008-.473l-.047.519z"></path><path d="M58.254.345c.005.008.006.009.01.016.06-.096.026-.08-.01-.016z"></path><path d="M37.548 1.784c.285.736-.311.991.098 1.804-.056-.327.226-1.335-.098-1.804z"></path><path d="M78.2 8.435c-.033.004-.066.006-.097-.007.039.033.069.036.097.007z"></path><path d="M37.646 3.588v.006l.042.077c-.018-.034-.029-.055-.042-.083z"></path><path d="M53.021.901c.014.148.037.261.062.368-.005-.086-.02-.192-.062-.368z"></path><path d="m56.919 2.043-.097-.113c.039.077.07.103.097.113z"></path><path d="M51.038 2.132c-.055-.063-.075-.179-.143-.063.008.043.015.072.024.102.023-.115.056-.172.119-.039z"></path><path d="M48.953 2.223c.016.06.03.111.045.168l.064-.048-.109-.12z"></path><path d="M9.238 10.767c-.056-.235-.095-.496-.127-.753.057.596-.243.821.127.753z"></path><path d="M78.319 8.086c-.047.208-.082.309-.119.349.024-.006.049-.019.073-.034.027-.123.047-.24.046-.315z"></path><path d="m51.165 8.784-.327-.111c.093.078.212.116.327.111z"></path><path d="m24.158 9.73-.068.107c.031.017.056-.01.068-.107z"></path><path d="M49.883 8.837c-.068-.294-.137-.465-.204-.574-.011.066-.024.121-.029.219l.233.355z"></path><path d="M9.11 10.005c0 .003.001.009.001.009s-.001-.006-.001-.009z"></path><path d="M6.987 12.084c.319.013.114-1.09.161-1.728.367-.328.202.809.351 1.371.228-.302.372-1.325.55-1.288.02.182.057.247.024.478.218-.89.741-.07.987-1.187.026.098.041.19.05.274-.07-.554-.1-1.117-.106-1.519.141-.024.232-.709.315.013-.087-.018-.082.275-.113.503l.135-.319c.177 1.035-.188.366-.155 1.136.276-.348.575-1.222.808-.935.092 1.016-.503.36-.168 1.255l-.36-.376c.331 1.596-.214-.104.101 1.604.468.277.486-.534.951-.259.075-.571-.072-.835.003-1.406.59-1.051.625 2.532 1.031 1.151.089-.685.071-1.975.439-1.312l-.057 1.156c.443.091.166-1.667.662-.917-.058.456-.323.399-.25.532.343.893.176-.663.403-.676l.101 1.017c.457-.186.929-.948 1.432-1.161-.011.304-.081.628.058.933.621-.542 1.394.051 2.057.609l.184-.895c.056.006.128.391.078.564.265.317-.022-.559.073-.911.134-.07.215.493.144.763.383-.773 1.118-1.686 1.633-.774l-.071.267c.377.333.276-1.827.657-1.029l-.052.16c.79.329 1.577-.528 2.252.752.02-1.273.795.508.716-1.26.498.843.396 1.167 1.053 1.709.17.069.163-1.119.352-1.318l.073.921.202-.987.229 1.093.172-.251c-.079-.05-.191-.402-.199-.668.265-.44.77.588.813 1.061l.643-.832c.013.372-.095.508-.17.751.303-.969.142.967.419.078-.062-.206-.017-.551-.023-.737.215.545.603.52.871.263l-.006.639c.53.123 1.069-.389 1.651-.422-.231-.279-.268-1.385-.105-1.504l.144.97c.063-.612-.207-.354-.037-1.109.226.096.231 1.097.131 1.424l.238-.358c.037.289-.013.447 0 .819.062-.613.531.942.606-.12l.037.289c.582-.037.82-.393 1.29-.479-.056-.842.145-.669.233-1.36.369.242.804.874 1.217.771.262-.441.031-.72.125-1.229.08.765.492.662.317 1.229.493-.163.63-.201 1.218-.872-.096-.31-.184-.441-.163-.706.106-.135.287.302.298.671l-.024.082c.628-1.204 1.81 2.109 2.259.469l-.025.081.526-.873c.279.113-.12.587.114 1.048.54-1.323 1.012.115 1.473-.772.56 2.233 1.421-.258 2.063 1.148l-.067-.53c.106-.532.19.293.303.407-.042-.412-.185-.468-.116-.764 1.152-.731 2.506.63 3.746 1.036.451.118.098-2.771.73-1.531l-.104.999c.835-1.239 1.837-.069 2.665-1.106-.042.23-.029.527-.115.527.219.711.686.007.663-.58.14.061.056.528.153.824.203.416.427-.938.556-.227.021.115-.042.235-.074.293.106-.354.567.064.418-.761.345.383.616-.395.897.086.138-.936.58.423.588-.892.024 1.356.615 1.069.804.423-.057.413.194.418.131.988.235-.024.444-.28.383-.976.481 1.614.845-1.324 1.145.751.685-.744 1.33-1.251 1.962-1.581-.003 1.354-.701.149-.648 1.568.589-.569.922-1.737 1.524-1.423.157.182-.081.589-.131.82.597-.575 1.161.109 1.691-.622-.001.126-.059.263-.112.366.104-.044.244.2.231-.416l-.103.167c-.171-.895.417-1.862.438-2.334-.18 1.762.532.446.243 2.672.069-.115.156-.406.142-.817.104.12.135.36.029.828.378-.333.247-.987.59-.972-.003.298-.073.413-.11.763.176-.579.355-1.159.644-.906-.02.18.012.414-.074.409.496-.088.868-1.542 1.409-.978-.184 1.293.179.427.187 1.547l.299-.332-.106-.544c.256.018.501-.789.714-.413l-.201.454.486-.194-.263-.435c.275-.567.007-1.418.344-1.094-.073.112.26.023.375.688v.003c.138-.352.281-.721.464-.437.038.36-.079 1.236-.055 1.476.156-.931.61-.236.806-1.228-.062.232-.086.82-.073.94l.134-.756c.11.247.123.365.086.833.354.152-.059-1.423.344-.796-.036.061-.024.175-.099.287.414.335.849-.451 1.226-.063.062 1.131-.355.263-.269 1.218.57-.18 1.24-1.316 1.772-1.001l-.095-.132c.171-1.582.36.816.682.088-.075.112-.145.874-.115.699.356.282.786-.334 1.393-.79l-.101.402c.193.38.564.253.787.456.103-.401.234-.325.199-.924.533 2.381 1.521-1.153 1.991.857-.078-.005-.219.334-.158.344l.588-.311c.026-.695-.029-.427-.092-.978.111-.4.302-.698.44-.683-.299.428-.112 1.108-.046 1.505.004-.213.065-.441.079-.658.159 1.261.196-1.381.506-.508l-.061.359c.168-.168.358-.63.509-.508-.024.805-.201.354-.284 1.008.228-.02.616-1.457.729-.639-.122.21-.26.198-.381.407.113.962.165.727.312.894l-.014-.022.325.468-.064-.266c.533-2.042.614-.312 1.167-1.626-.535 1.242-.156.736-.302 1.634.063.262.172.56.098.808.272-.706.217.607.608-.426-.028.291.186.05.046.773.26-.201.016-.511.084-.872.498-.957.655 1.321 1.359.047.521-.486.756-1.447 1.247-1.863.064.484-.282 1.033-.282 1.033.155.462.333.411.598.116-.084.244-.075.465-.065.8.179-.049.288-1.032.438-.57-.093.315-.229.821-.363 1.131.24-.233.527-.739.778-.965-.034.511-.257.741-.385 1.058.267-.188.671-.356.886-1.14l-.098-.309c.092-.023-.079.69-.166.825-.307.59-.235-.323-.196-.614l.179-.16c.146-1.715-.639.173-.913.026l.33-1.21-.475.971c-.011-.331.057-1.026.235-1.186-.115-.645-.262.406-.335-.303-.004-.109.016-.167.042-.213l-.269.332c.082-.252.104-.876.205-.676-.269-.774-.755.823-.753-.135l.044-.07c-.588.33-.19.896-.738 1.896l.065-2.279-.186.905c-.05-.041-.146-.127-.075-.486-.289.587-.021.4-.223.967-.141-.877-.769.297-.63-1.16-.187.679.178.562-.166 1.008.13-1.564-.356.229-.5-.513.178-.795.351-.343.203-1.087-.32 1.34-.429-.354-.667-.117-.145 1.08-.496.399-.878.721.064-.361-.569-.67-.845-1.1l.029-.181c-.181 1.088-.483.844-.744 1.042.077-.654.146-.908.307-1.187l-.226-.021c-.089.345-.178.522-.335.631l.139-.813c-.306.012-.695.887-1.028.316-.091.764.104 2.153-.343 2.634.023-.415.072-1.123.193-1.284-.039.052-.154.334-.207.152l.225-.684c-.146-.319-.145.574-.277.499.056-.59-.065-.429-.003-.896.041-.055.1.253.174.025-.147-.117-.308-.481-.332-.934-.016.337-.069.795-.191.863-.302.021-.041-.718-.19-1.035-.107.405-.263-.034-.341.849-.087-.012-.069-.425-.084-.666-.187.378-.733.058-.631 1.01l.034.064c-.009.019-.018.019-.028.039h.001H69c-.568.84-1.012-.579-1.541-.237l.021-.296c-.321.314-.68.149-.93.77-.088-.007-.178-.555-.12-.904-.242.203-.284.541-.59.039.258-.508-.056-.461.257-.369-.284-.267-.33-.743-.69.054.146-.754-.18-.964-.333-.742l.185.55c-.165.104-.302.032-.44-.038l.122-.994c-.567-1.236-1.189 2.022-1.58-.025-.187.691.316.503.142 1.314-.274-.146-.521-1.589-.611-1.595-.372-.567-.405 1.444-.798 1.051.043.357.064 1.31-.242 1.634-.275-.143-.309-1.506-.124-1.785.068-.027.099.087.093.207.094-.125.218-.273.115-.664l-.045.354c-.131-.368-.521-.345-.417-.925-.222.331-.104.58.05.771-.354-.535-.568-.028-.934-.378.056.196.103.615.044.61-.538-.443-.251.674-.621.828-.201-.544.093-1.295-.284-.843-.223-.369-.037-.945.058-1.234-.349.684-.632-.455-.828-.582L59.142 0c-.109.17-.198.164-.288.162l.098.713c-.104-.126-.194-.128-.19-.425-.111.466.074 1.185-.144 1.821-.138-.362-.427.386-.472-.56.439.323-.045-.949.33-1.1-.073.112-.161.107-.267-.019-.016-.105.016-.195.045-.249-.422-.848-.198 1.067-.636 1.043.057-.532-.102-1.011-.173-.897.177.012.084.889-.077 1.296-.28-.417-.303.307-.449.257l.167.196c-.055.532-.194.461-.388.628-.019-.415.176-.284.105-.468-.21.937-.494-.975-.791-.34-.143-.357-.022-1-.147-1.242-.332.697-.375-.722-.726-.145.112.714.127.538-.114 1.24l.578-.515-.362 1.048c.175.007.365-.457.472-.337-.172.587-.155.408-.065 1.001-.251-1.069-.467.635-.752-.085l-.016-1.769c-.433-.781-.731.924-1.281.49l.181.304c-.06.705-.334.104-.503.394.004-.593-.111-.806-.194-1.172.019.438-.4-.032-.421 1.151l-.262-.775c-.448-.311-.455 1.697-.88 1.505.108-.646-.096-1.063.174-1.528-.142-.003-.271-.108-.262.301-.094-.367-.365.805-.512.248-.051.263-.05.884-.209.841-.021-.12-.009-.293-.009-.293.009.292-.232.408-.073 1.058-.494-1.829-1.195.185-1.631-1.387-.298.211-.658.417-.934.471.011-.178-.012-.295.044-.235-.407-.535-.162 1.709-.623 1.112-.265-.947.208-.527.054-.884-.148-1.944-.514.288-.859-.837l.065-.117c-.257-.652-.513.76-.885.637 0 0 .009-.174-.013-.295-.2 1.008-.654 1.363-.989 1.659.068-.768.138-.412.03-1.183-.151.12.112 1.241-.189 1.475-.125-.411-.371-.762-.446-1.586l.294-.062c-.21-1.06-.382.059-.548-.118l-.006-.468c-.447.178-.387 1.354-.879 1.299l.071.351c-.198 1.181-.262-.643-.477.239l-.15-1.178c-.16.295-.548 1.179-.849 1.419.124-.887.466-1.357.664-1.891-.175.002-.589.122-.644.71.063-.118.134-.412.215-.234-.158.941-.41 1.415-.758 1.414-.084-2.298-.94-.521-1.309-2.28-.558.89-1.243-.278-1.951-.093.377 1.765-.205.065-.034 1.892-.158.129-.224.104-.247-.015l-.581-1.058c-.157-.524.13-.414.086-.824-.376-.115-.208-.765-.485-1.234.097.651-.061.946-.286.711l.354.823c-.44 1.01-.552-1.505-.997-.505l.121-.587c-.241.356-.975.059-1.124 1.548-.063-.207-.161-.703-.055-.844-.646-.173-1.283 1.669-1.839.802l.014-.451c-.107.139-.141.856-.321.417-.007-.186.014-.45-.043-.473-.051.159-.253.808-.428.559l.095-.514c-.658-.539-.848 1.297-1.338 1.643-.1-1.317-.615-1.708-.871-1.902l-.007-.187c-.724-.107-1.124 1.185-1.744 1.753-.519-1.398-1.432-.491-2.151-1.242.119.231.063 1.027-.044 1.168-.175-.255-.356.946-.425-.263l.057.019c-.207-1.175-.5-.835-.749-.851l.08 1.583c-.819-2.25-1.631.97-2.137-1.063-.126.407-.319.416-.445.822l-.054-.848c-.447-.184-.671-.274-1.189-.033l.065-.613c-.305-.032-.204 2.471-.479 2.541l-.174-1.258c-.525.061-1.13-1.02-1.569.163-.004-.186-.014-.553.067-.609-.249-.018-1.01-.793-.804.938-.082-1.131-.548-.075-.799.442l-.011-.838c-.169 1.082-.158 1.374-.474 1.691-.086-.104-.112-.663.007-.457-.292-.419-.155.805-.504.381l.085-.541c-.275-.046-.235.238-.346.87-.15.346-.529-.177-.616-.929-.008.462-.119 1.087-.293.881-.039-.284.009-.465.033-.553-.488-.54-.617 1.007-.978.205-.022-.276-.051-.414-.082-.495.361.001.653.031.63.094-.046-.77-.344-.89-.177-1.964-.196.592-.522 1.874-.826 1.527-.018-.074-.035-.146-.053-.265l.024-.088c-.069-.073-.124.002-.172.134-.097-.121-.159-.212-.247-.219-.068-.635-.351-.325-.497-.349.058.841-.14.716.076 1.402-.026-.06.021-.103.116-.143.021-.026.046-.04.057-.091l-.006.074c.094-.029.218-.055.357-.075-.091.434-.19.8-.377.342-.051.538-.104 1.097-.129 1.369-.263-1.164-.679-1.778-.77-2.5-.417.497-1.023.367-1.226 1.965-.117.21-.167-.445-.227-.692.065-.163.153-.143.182-.372-.232.419-.738.197-.748 1.307-.34-.483.132-1.025-.296-.825l.044-.341c-.927-1.736-1.279 2.872-2.32.638.07.137.105.2.126.385-1.112-.966-2.21 1.033-3.32-.541-.31-.316-.327.391-.503.931l-.084-.905-.298 1.05c-.44.771-.813-2.213-1.36-.759l.08.609c-.206-.112-.646.368-.618-.334-.02.112-.062.636-.145.318l-.009-.473-.498.819c-.392-.338.051-1.883-.515-1.968C.33 4.627-.06 5.829.02 6.146c.085.022.218.293.226.768l-.195.248c-.034 1.398-.19 2.83.299 3.799l.337-.858.111.677-.285.046c.163.635.265.069.378-.318.028.36.077.611.146.744l.323-1.339c.045.546-.142 1.086.084 1.385.151-.621-.157-1.224.097-1.633.166.632.124 1.15.309.605.03.359-.008.589-.082.748.166-.434.447-.188.526-.933.178.782.567-.211.568 1.111.05-.316.284-1.041.438-1.099-.259 1.587.583.086.539 1.783.185-1.426.75-.642 1.104-1.437-.018.113-.053.343-.088.271.213.115.285.546.426.809-.003-1.176.315-1.456.47-2.188.287 1.125-.117 1.386-.007 2.472-.039-.952.419-.966.309-1.757.217.694.179.335.309 1.306-.01-1.471.176-.256.31-1.164.307.714.117 1.374.414.916.162.446-.099.976-.099.976zm7.281-2.874c0 .009.001.014.001.018-.063.022-.115.043-.149.056.03-.016.072-.037.148-.074zm.617-.046c-.077-.028-.172-.029-.271-.019-.038-.289-.032-.59.03-.578-.021.197.133.357.241.597zm-1.629-5.766c.09-.124.131.04.153.212-.044.017-.096.048-.162.109-.002.031-.004.068-.006.104 0-.161.003-.312.015-.425z"></path><path d="M13.144 4.513c-.013.02-.019.055-.036.063.023.073.046.135.067.187.007-.091.014-.18.02-.267l-.051.017z"></path><path d="m68.993 3.613-.012-.021c.008.035.016.068.019.123-.004-.045-.005-.068-.007-.102z"></path><path d="m23.504 10.196-.017-.214-.04.191z"></path><path d="M72.097 6.793c-.002.074.003.152.021.221.003-.056-.008-.134-.021-.221z"></path><path d="m73.505 7.148.166.322c-.067-.179-.121-.267-.166-.322z"></path><path d="M74.55 7.692c.028-.149.048-.256.067-.356l-.002-.005-.065.361z"></path><path d="M57.015 7.687c-.015.003-.03.015-.043.037-.099.163-.032.098.043-.037z"></path><path d="M62.287 5.783c-.061.151-.12.299-.181.393.092.067.164.087.181-.393z"></path><path d="M51.201 8.797v-.015c-.013.004-.023.001-.036.002l.036.013z"></path><path d="M61.862 6.151c.089.172.168.139.244.024-.075-.059-.163-.149-.244-.024z"></path><path d="m79.191 8.79.046.043c.009-.055.02-.1.03-.133l-.076.09z"></path><path d="m79.268 8.7.075-.088c-.027-.005-.051-.002-.075.088z"></path><path d="m79.502 8.423-.159.189c.042.009.089.043.159-.189z"></path><path d="m77.825 8.168-.065.3c.018-.061.04-.158.065-.3z"></path><path d="M77.375 8.184c.094.086.157.688.332.521l.053-.237c-.141.437-.205-.778-.385-.284z"></path><path d="m76.073 4.147.346.293c-.02-.333-.047-.781.138-.83-.346-1.034-.002.73-.484.537z"></path><path d="M74.95 3.54c.226-.126.058-.47.092-.65-.169.278-.209.348-.092.65z"></path><path d="m66.36 2.741.063-.764c-.165.099-.018.297-.063.764z"></path><path d="m64.54 6.641.129.481.103-.699z"></path><path d="m63.803 1.142.074-.107-.278.269z"></path><path d="m49.296 1.462.083.942c.1-.173.084-1.235-.083-.942z"></path><path d="M43.139 2.726c-.094-.468-.286-.761-.366-.291.142.056.302.417.366.291z"></path><path d="m24.566 2.517.099-.325-.212.28z"></path></g> </svg>',
							buttonContent = '<span class="qodef-m-text">' + buttonText + '</span><span class="qodef-m-wave">' + buttonIcon + '</span><span class="qodef-m-wave-fake">' + buttonIcon + '</span>';

						$thisButton.empty().append( buttonContent );
					}
				);
			}
		}
	};

})( jQuery );
