<?php

if ( ! function_exists( 'ginevra_get_search_page_excerpt_length' ) ) {
	/**
	 * Function that return number of characters for excerpt on search page
	 *
	 * @return int
	 */
	function ginevra_get_search_page_excerpt_length() {
		$length = apply_filters( 'ginevra_filter_post_excerpt_length', 180 );

		return intval( $length );
	}
}

if ( ! function_exists( 'ginevra_override_search_block_templates' ) ) {
	/**
	 * Function that override `core/search` block template
	 *
	 * @see register_block_core_search()
	 */
	function ginevra_override_search_block_templates( $atts ) {
		if ( ! empty( $atts ) && isset( $atts['render_callback'] ) && 'render_block_core_search' === $atts['render_callback'] && function_exists( 'styles_for_block_core_search' ) ) {
			$atts['render_callback'] = 'ginevra_render_block_core_search';
		}

		return $atts;
	}

	add_filter( 'block_type_metadata_settings', 'ginevra_override_search_block_templates' );
}

if ( ! function_exists( 'ginevra_render_block_core_search' ) ) {
	/**
	 * Function that dynamically renders the `core/search` block
	 *
	 * @param array $attributes - the block attributes
	 *
	 * @return string - the search block markup
	 *
	 * @see render_block_core_search()
	 */
	function ginevra_render_block_core_search( $attributes ) {
		static $instance_id = 0;

		$attributes = wp_parse_args(
			$attributes,
			array(
				'label'      => esc_html__( 'Search', 'ginevra' ),
				'buttonText' => esc_html__( 'Search', 'ginevra' ),
			)
		);

		$input_id        = 'qodef-search-form-' . ++ $instance_id;
		$show_label      = ! empty( $attributes['showLabel'] );
		$use_icon_button = ! empty( $attributes['buttonUseIcon'] );
		$show_input      = ! ( ! empty( $attributes['buttonPosition'] ) && 'button-only' === $attributes['buttonPosition'] );
		$show_button     = ! ( ! empty( $attributes['buttonPosition'] ) && 'no-button' === $attributes['buttonPosition'] );
		$label_markup    = '';
		$input_markup    = '';
		$button_markup   = '';
		$inline_styles   = styles_for_block_core_search( $attributes );
        // function get_color_classes_for_block_core_search doesn't exist in wp 5.8 and below
        $color_classes    = function_exists( 'get_color_classes_for_block_core_search' ) ? get_color_classes_for_block_core_search( $attributes ) : '';
        $is_button_inside = ! empty( $attributes['buttonPosition'] ) && 'button-inside' === $attributes['buttonPosition'];
        // border color classes need to be applied to the elements that have a border color
        // function get_border_color_classes_for_block_core_search doesn't exist in wp 5.8 and below
        $border_color_classes = function_exists( 'get_border_color_classes_for_block_core_search' ) ? get_border_color_classes_for_block_core_search( $attributes ) : '';

		if ( $show_label ) {
			if ( ! empty( $attributes['label'] ) ) {
				$label_markup = sprintf(
					'<label for="%s" class="qodef-search-form-label">%s</label>',
					$input_id,
					$attributes['label']
				);
			} else {
				$label_markup = sprintf(
					'<label for="%s" class="screen-reader-text">%s</label>',
					$input_id,
					esc_html__( 'Search', 'ginevra' )
				);
			}
		}

		if ( $show_input ) {
            $input_classes = ! $is_button_inside ? $border_color_classes : '';
            $input_markup  = sprintf(
                '<input type="search" id="%s" class="qodef-search-form-field %s" name="s" value="%s" placeholder="%s" %s required />',
                $input_id,
                esc_attr( $input_classes ),
                esc_attr( get_search_query() ),
                esc_attr( $attributes['placeholder'] ),
                // key input doesn't exist in wp 5.8 and below
                array_key_exists( 'input', $inline_styles ) ? $inline_styles['input'] : ''
            );
		}

		if ( $show_button ) {
            $button_internal_markup = '';
            $button_classes         = $color_classes;
            $button_classes         .= ! empty( $attributes['buttonPosition'] ) ? ' qodef--' . $attributes['buttonPosition'] : '';

            if ( ! $is_button_inside ) {
                $button_classes .= ' ' . $border_color_classes;
            }
            if ( ! $use_icon_button ) {
                if ( ! empty( $attributes['buttonText'] ) ) {
                    $button_internal_markup = esc_html( $attributes['buttonText'] );
                }
            } else {
                $button_classes         .= ' qodef--has-icon';
                $button_internal_markup = ginevra_get_svg_icon( 'search' );
            }

            $button_markup = sprintf(
                '<button type="submit" class="qodef-search-form-button %s" %s>%s</button>',
                esc_attr( $button_classes ),
                // key button doesn't exist in wp 5.8 and below
                array_key_exists( 'button', $inline_styles ) ? $inline_styles['button'] : '',
                $button_internal_markup
            );
		}

		$field_markup = sprintf(
			'<div class="qodef-search-form-inner"%s>%s</div>',
			$inline_styles['wrapper'],
			$input_markup . $button_markup
		);

		return sprintf(
			'<form role="search" method="get" class="qodef-search-form" action="%s">%s</form>',
			esc_url( home_url( '/' ) ),
			$label_markup . $field_markup
		);
	}
}
